# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class GenerateDiscoveryReportForDownloadDetails(object):
    """
    Details to generate a downloadable discovery report.
    """

    #: A constant which can be used with the report_format property of a GenerateDiscoveryReportForDownloadDetails.
    #: This constant has a value of "PDF"
    REPORT_FORMAT_PDF = "PDF"

    #: A constant which can be used with the report_format property of a GenerateDiscoveryReportForDownloadDetails.
    #: This constant has a value of "XLS"
    REPORT_FORMAT_XLS = "XLS"

    def __init__(self, **kwargs):
        """
        Initializes a new GenerateDiscoveryReportForDownloadDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param discovery_job_id:
            The value to assign to the discovery_job_id property of this GenerateDiscoveryReportForDownloadDetails.
        :type discovery_job_id: str

        :param report_format:
            The value to assign to the report_format property of this GenerateDiscoveryReportForDownloadDetails.
            Allowed values for this property are: "PDF", "XLS"
        :type report_format: str

        """
        self.swagger_types = {
            'discovery_job_id': 'str',
            'report_format': 'str'
        }

        self.attribute_map = {
            'discovery_job_id': 'discoveryJobId',
            'report_format': 'reportFormat'
        }

        self._discovery_job_id = None
        self._report_format = None

    @property
    def discovery_job_id(self):
        """
        Gets the discovery_job_id of this GenerateDiscoveryReportForDownloadDetails.
        The OCID of the discovery job.


        :return: The discovery_job_id of this GenerateDiscoveryReportForDownloadDetails.
        :rtype: str
        """
        return self._discovery_job_id

    @discovery_job_id.setter
    def discovery_job_id(self, discovery_job_id):
        """
        Sets the discovery_job_id of this GenerateDiscoveryReportForDownloadDetails.
        The OCID of the discovery job.


        :param discovery_job_id: The discovery_job_id of this GenerateDiscoveryReportForDownloadDetails.
        :type: str
        """
        self._discovery_job_id = discovery_job_id

    @property
    def report_format(self):
        """
        **[Required]** Gets the report_format of this GenerateDiscoveryReportForDownloadDetails.
        Format of the report.

        Allowed values for this property are: "PDF", "XLS"


        :return: The report_format of this GenerateDiscoveryReportForDownloadDetails.
        :rtype: str
        """
        return self._report_format

    @report_format.setter
    def report_format(self, report_format):
        """
        Sets the report_format of this GenerateDiscoveryReportForDownloadDetails.
        Format of the report.


        :param report_format: The report_format of this GenerateDiscoveryReportForDownloadDetails.
        :type: str
        """
        allowed_values = ["PDF", "XLS"]
        if not value_allowed_none_or_none_sentinel(report_format, allowed_values):
            raise ValueError(
                "Invalid value for `report_format`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._report_format = report_format

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SqlTuningAdvisorTaskSummaryFindingCounts(object):
    """
    The number of findings in the SQL Tuning Advisor summary report.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SqlTuningAdvisorTaskSummaryFindingCounts object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param recommended_sql_profile:
            The value to assign to the recommended_sql_profile property of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :type recommended_sql_profile: int

        :param implemented_sql_profile:
            The value to assign to the implemented_sql_profile property of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :type implemented_sql_profile: int

        :param index:
            The value to assign to the index property of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :type index: int

        :param restructure:
            The value to assign to the restructure property of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :type restructure: int

        :param statistics:
            The value to assign to the statistics property of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :type statistics: int

        :param alternate_plan:
            The value to assign to the alternate_plan property of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :type alternate_plan: int

        """
        self.swagger_types = {
            'recommended_sql_profile': 'int',
            'implemented_sql_profile': 'int',
            'index': 'int',
            'restructure': 'int',
            'statistics': 'int',
            'alternate_plan': 'int'
        }

        self.attribute_map = {
            'recommended_sql_profile': 'recommendedSqlProfile',
            'implemented_sql_profile': 'implementedSqlProfile',
            'index': 'index',
            'restructure': 'restructure',
            'statistics': 'statistics',
            'alternate_plan': 'alternatePlan'
        }

        self._recommended_sql_profile = None
        self._implemented_sql_profile = None
        self._index = None
        self._restructure = None
        self._statistics = None
        self._alternate_plan = None

    @property
    def recommended_sql_profile(self):
        """
        **[Required]** Gets the recommended_sql_profile of this SqlTuningAdvisorTaskSummaryFindingCounts.
        The number of distinct SQL statements with recommended SQL profiles.


        :return: The recommended_sql_profile of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :rtype: int
        """
        return self._recommended_sql_profile

    @recommended_sql_profile.setter
    def recommended_sql_profile(self, recommended_sql_profile):
        """
        Sets the recommended_sql_profile of this SqlTuningAdvisorTaskSummaryFindingCounts.
        The number of distinct SQL statements with recommended SQL profiles.


        :param recommended_sql_profile: The recommended_sql_profile of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :type: int
        """
        self._recommended_sql_profile = recommended_sql_profile

    @property
    def implemented_sql_profile(self):
        """
        **[Required]** Gets the implemented_sql_profile of this SqlTuningAdvisorTaskSummaryFindingCounts.
        The number of distinct SQL statements with implemented SQL profiles.


        :return: The implemented_sql_profile of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :rtype: int
        """
        return self._implemented_sql_profile

    @implemented_sql_profile.setter
    def implemented_sql_profile(self, implemented_sql_profile):
        """
        Sets the implemented_sql_profile of this SqlTuningAdvisorTaskSummaryFindingCounts.
        The number of distinct SQL statements with implemented SQL profiles.


        :param implemented_sql_profile: The implemented_sql_profile of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :type: int
        """
        self._implemented_sql_profile = implemented_sql_profile

    @property
    def index(self):
        """
        **[Required]** Gets the index of this SqlTuningAdvisorTaskSummaryFindingCounts.
        The number of distinct SQL statements with index recommendations.


        :return: The index of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        """
        Sets the index of this SqlTuningAdvisorTaskSummaryFindingCounts.
        The number of distinct SQL statements with index recommendations.


        :param index: The index of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :type: int
        """
        self._index = index

    @property
    def restructure(self):
        """
        **[Required]** Gets the restructure of this SqlTuningAdvisorTaskSummaryFindingCounts.
        The number of distinct SQL statements with restructured SQL recommendations.


        :return: The restructure of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :rtype: int
        """
        return self._restructure

    @restructure.setter
    def restructure(self, restructure):
        """
        Sets the restructure of this SqlTuningAdvisorTaskSummaryFindingCounts.
        The number of distinct SQL statements with restructured SQL recommendations.


        :param restructure: The restructure of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :type: int
        """
        self._restructure = restructure

    @property
    def statistics(self):
        """
        **[Required]** Gets the statistics of this SqlTuningAdvisorTaskSummaryFindingCounts.
        The number of distinct SQL statements with stale or missing optimizer statistics recommendations.


        :return: The statistics of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :rtype: int
        """
        return self._statistics

    @statistics.setter
    def statistics(self, statistics):
        """
        Sets the statistics of this SqlTuningAdvisorTaskSummaryFindingCounts.
        The number of distinct SQL statements with stale or missing optimizer statistics recommendations.


        :param statistics: The statistics of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :type: int
        """
        self._statistics = statistics

    @property
    def alternate_plan(self):
        """
        **[Required]** Gets the alternate_plan of this SqlTuningAdvisorTaskSummaryFindingCounts.
        The number of distinct SQL statements with alternative plan recommendations.


        :return: The alternate_plan of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :rtype: int
        """
        return self._alternate_plan

    @alternate_plan.setter
    def alternate_plan(self, alternate_plan):
        """
        Sets the alternate_plan of this SqlTuningAdvisorTaskSummaryFindingCounts.
        The number of distinct SQL statements with alternative plan recommendations.


        :param alternate_plan: The alternate_plan of this SqlTuningAdvisorTaskSummaryFindingCounts.
        :type: int
        """
        self._alternate_plan = alternate_plan

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PutMessagesDetails(object):
    """
    Object that represents an array of messages to emit to a stream.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PutMessagesDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param messages:
            The value to assign to the messages property of this PutMessagesDetails.
        :type messages: list[oci.streaming.models.PutMessagesDetailsEntry]

        """
        self.swagger_types = {
            'messages': 'list[PutMessagesDetailsEntry]'
        }

        self.attribute_map = {
            'messages': 'messages'
        }

        self._messages = None

    @property
    def messages(self):
        """
        **[Required]** Gets the messages of this PutMessagesDetails.
        The array of messages to put into a stream.


        :return: The messages of this PutMessagesDetails.
        :rtype: list[oci.streaming.models.PutMessagesDetailsEntry]
        """
        return self._messages

    @messages.setter
    def messages(self, messages):
        """
        Sets the messages of this PutMessagesDetails.
        The array of messages to put into a stream.


        :param messages: The messages of this PutMessagesDetails.
        :type: list[oci.streaming.models.PutMessagesDetailsEntry]
        """
        self._messages = messages

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AuthenticateUserResult(object):
    """
    See ValidAuthenticateUserResult, BadUserStateAuthenticateUserResult, UserNotFoundAuthenticateUserResult, TenantNotFoundAuthenticateUserResult
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AuthenticateUserResult object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param tenant_input:
            The value to assign to the tenant_input property of this AuthenticateUserResult.
        :type tenant_input: str

        :param user_input:
            The value to assign to the user_input property of this AuthenticateUserResult.
        :type user_input: str

        """
        self.swagger_types = {
            'tenant_input': 'str',
            'user_input': 'str'
        }

        self.attribute_map = {
            'tenant_input': 'tenantInput',
            'user_input': 'userInput'
        }

        self._tenant_input = None
        self._user_input = None

    @property
    def tenant_input(self):
        """
        **[Required]** Gets the tenant_input of this AuthenticateUserResult.
        The tenant name.


        :return: The tenant_input of this AuthenticateUserResult.
        :rtype: str
        """
        return self._tenant_input

    @tenant_input.setter
    def tenant_input(self, tenant_input):
        """
        Sets the tenant_input of this AuthenticateUserResult.
        The tenant name.


        :param tenant_input: The tenant_input of this AuthenticateUserResult.
        :type: str
        """
        self._tenant_input = tenant_input

    @property
    def user_input(self):
        """
        **[Required]** Gets the user_input of this AuthenticateUserResult.
        The user name.


        :return: The user_input of this AuthenticateUserResult.
        :rtype: str
        """
        return self._user_input

    @user_input.setter
    def user_input(self, user_input):
        """
        Sets the user_input of this AuthenticateUserResult.
        The user name.


        :param user_input: The user_input of this AuthenticateUserResult.
        :type: str
        """
        self._user_input = user_input

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PrivateAddresses(object):
    """
    A pair of VCN OCID and private IP address prefix in CIDR notation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new PrivateAddresses object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param vcn_id:
            The value to assign to the vcn_id property of this PrivateAddresses.
        :type vcn_id: str

        :param addresses:
            The value to assign to the addresses property of this PrivateAddresses.
        :type addresses: str

        """
        self.swagger_types = {
            'vcn_id': 'str',
            'addresses': 'str'
        }

        self.attribute_map = {
            'vcn_id': 'vcnId',
            'addresses': 'addresses'
        }

        self._vcn_id = None
        self._addresses = None

    @property
    def vcn_id(self):
        """
        **[Required]** Gets the vcn_id of this PrivateAddresses.
        The `OCID`__ of the VCN.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The vcn_id of this PrivateAddresses.
        :rtype: str
        """
        return self._vcn_id

    @vcn_id.setter
    def vcn_id(self, vcn_id):
        """
        Sets the vcn_id of this PrivateAddresses.
        The `OCID`__ of the VCN.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param vcn_id: The vcn_id of this PrivateAddresses.
        :type: str
        """
        self._vcn_id = vcn_id

    @property
    def addresses(self):
        """
        **[Required]** Gets the addresses of this PrivateAddresses.
        A private IP address or CIDR IP address range.


        :return: The addresses of this PrivateAddresses.
        :rtype: str
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """
        Sets the addresses of this PrivateAddresses.
        A private IP address or CIDR IP address range.


        :param addresses: The addresses of this PrivateAddresses.
        :type: str
        """
        self._addresses = addresses

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .error_entity import ErrorEntity
from .service_definition import ServiceDefinition
from .service_environment import ServiceEnvironment
from .service_environment_collection import ServiceEnvironmentCollection
from .service_environment_end_point_overview import ServiceEnvironmentEndPointOverview
from .service_environment_summary import ServiceEnvironmentSummary

# Maps type names to classes for service_manager_proxy services.
service_manager_proxy_type_mapping = {
    "ErrorEntity": ErrorEntity,
    "ServiceDefinition": ServiceDefinition,
    "ServiceEnvironment": ServiceEnvironment,
    "ServiceEnvironmentCollection": ServiceEnvironmentCollection,
    "ServiceEnvironmentEndPointOverview": ServiceEnvironmentEndPointOverview,
    "ServiceEnvironmentSummary": ServiceEnvironmentSummary
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DataCollectionOptions(object):
    """
    Indicates user preferences for the various diagnostic collection options for the VM cluster/Cloud VM cluster/VMBM DBCS.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DataCollectionOptions object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_diagnostics_events_enabled:
            The value to assign to the is_diagnostics_events_enabled property of this DataCollectionOptions.
        :type is_diagnostics_events_enabled: bool

        """
        self.swagger_types = {
            'is_diagnostics_events_enabled': 'bool'
        }

        self.attribute_map = {
            'is_diagnostics_events_enabled': 'isDiagnosticsEventsEnabled'
        }

        self._is_diagnostics_events_enabled = None

    @property
    def is_diagnostics_events_enabled(self):
        """
        Gets the is_diagnostics_events_enabled of this DataCollectionOptions.
        Indicates whether diagnostic collection is enabled for the VM cluster/Cloud VM cluster/VMBM DBCS. Enabling diagnostic collection allows you to receive Events service notifications for guest VM issues. Diagnostic collection also allows Oracle to provide enhanced service and proactive support for your Exadata system. You can enable diagnostic collection during VM cluster/Cloud VM cluster provisioning. You can also disable or enable it at any time using the `UpdateVmCluster` or `updateCloudVmCluster` API.


        :return: The is_diagnostics_events_enabled of this DataCollectionOptions.
        :rtype: bool
        """
        return self._is_diagnostics_events_enabled

    @is_diagnostics_events_enabled.setter
    def is_diagnostics_events_enabled(self, is_diagnostics_events_enabled):
        """
        Sets the is_diagnostics_events_enabled of this DataCollectionOptions.
        Indicates whether diagnostic collection is enabled for the VM cluster/Cloud VM cluster/VMBM DBCS. Enabling diagnostic collection allows you to receive Events service notifications for guest VM issues. Diagnostic collection also allows Oracle to provide enhanced service and proactive support for your Exadata system. You can enable diagnostic collection during VM cluster/Cloud VM cluster provisioning. You can also disable or enable it at any time using the `UpdateVmCluster` or `updateCloudVmCluster` API.


        :param is_diagnostics_events_enabled: The is_diagnostics_events_enabled of this DataCollectionOptions.
        :type: bool
        """
        self._is_diagnostics_events_enabled = is_diagnostics_events_enabled

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SummarizeOperationsInsightsWarehouseResourceUsageAggregation(object):
    """
    Details of resource usage by an Operations Insights Warehouse resource.
    """

    #: A constant which can be used with the lifecycle_state property of a SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
    #: This constant has a value of "CREATING"
    LIFECYCLE_STATE_CREATING = "CREATING"

    #: A constant which can be used with the lifecycle_state property of a SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
    #: This constant has a value of "UPDATING"
    LIFECYCLE_STATE_UPDATING = "UPDATING"

    #: A constant which can be used with the lifecycle_state property of a SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
    #: This constant has a value of "ACTIVE"
    LIFECYCLE_STATE_ACTIVE = "ACTIVE"

    #: A constant which can be used with the lifecycle_state property of a SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
    #: This constant has a value of "DELETING"
    LIFECYCLE_STATE_DELETING = "DELETING"

    #: A constant which can be used with the lifecycle_state property of a SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
    #: This constant has a value of "DELETED"
    LIFECYCLE_STATE_DELETED = "DELETED"

    #: A constant which can be used with the lifecycle_state property of a SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
    #: This constant has a value of "FAILED"
    LIFECYCLE_STATE_FAILED = "FAILED"

    def __init__(self, **kwargs):
        """
        Initializes a new SummarizeOperationsInsightsWarehouseResourceUsageAggregation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        :type id: str

        :param cpu_used:
            The value to assign to the cpu_used property of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        :type cpu_used: float

        :param storage_used_in_gbs:
            The value to assign to the storage_used_in_gbs property of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        :type storage_used_in_gbs: float

        :param lifecycle_state:
            The value to assign to the lifecycle_state property of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
            Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type lifecycle_state: str

        """
        self.swagger_types = {
            'id': 'str',
            'cpu_used': 'float',
            'storage_used_in_gbs': 'float',
            'lifecycle_state': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'cpu_used': 'cpuUsed',
            'storage_used_in_gbs': 'storageUsedInGBs',
            'lifecycle_state': 'lifecycleState'
        }

        self._id = None
        self._cpu_used = None
        self._storage_used_in_gbs = None
        self._lifecycle_state = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        OPSI Warehouse OCID


        :return: The id of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        OPSI Warehouse OCID


        :param id: The id of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        :type: str
        """
        self._id = id

    @property
    def cpu_used(self):
        """
        Gets the cpu_used of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        Number of OCPUs used by OPSI Warehouse ADW. Can be fractional.


        :return: The cpu_used of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        :rtype: float
        """
        return self._cpu_used

    @cpu_used.setter
    def cpu_used(self, cpu_used):
        """
        Sets the cpu_used of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        Number of OCPUs used by OPSI Warehouse ADW. Can be fractional.


        :param cpu_used: The cpu_used of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        :type: float
        """
        self._cpu_used = cpu_used

    @property
    def storage_used_in_gbs(self):
        """
        Gets the storage_used_in_gbs of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        Storage by OPSI Warehouse ADW in GB.


        :return: The storage_used_in_gbs of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        :rtype: float
        """
        return self._storage_used_in_gbs

    @storage_used_in_gbs.setter
    def storage_used_in_gbs(self, storage_used_in_gbs):
        """
        Sets the storage_used_in_gbs of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        Storage by OPSI Warehouse ADW in GB.


        :param storage_used_in_gbs: The storage_used_in_gbs of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        :type: float
        """
        self._storage_used_in_gbs = storage_used_in_gbs

    @property
    def lifecycle_state(self):
        """
        **[Required]** Gets the lifecycle_state of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        Possible lifecycle states

        Allowed values for this property are: "CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The lifecycle_state of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        :rtype: str
        """
        return self._lifecycle_state

    @lifecycle_state.setter
    def lifecycle_state(self, lifecycle_state):
        """
        Sets the lifecycle_state of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        Possible lifecycle states


        :param lifecycle_state: The lifecycle_state of this SummarizeOperationsInsightsWarehouseResourceUsageAggregation.
        :type: str
        """
        allowed_values = ["CREATING", "UPDATING", "ACTIVE", "DELETING", "DELETED", "FAILED"]
        if not value_allowed_none_or_none_sentinel(lifecycle_state, allowed_values):
            lifecycle_state = 'UNKNOWN_ENUM_VALUE'
        self._lifecycle_state = lifecycle_state

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AdvisorReport(object):
    """
    Pre-Migration advisor report details.
    """

    #: A constant which can be used with the result property of a AdvisorReport.
    #: This constant has a value of "FATAL"
    RESULT_FATAL = "FATAL"

    #: A constant which can be used with the result property of a AdvisorReport.
    #: This constant has a value of "BLOCKER"
    RESULT_BLOCKER = "BLOCKER"

    #: A constant which can be used with the result property of a AdvisorReport.
    #: This constant has a value of "WARNING"
    RESULT_WARNING = "WARNING"

    #: A constant which can be used with the result property of a AdvisorReport.
    #: This constant has a value of "INFORMATIONAL"
    RESULT_INFORMATIONAL = "INFORMATIONAL"

    #: A constant which can be used with the result property of a AdvisorReport.
    #: This constant has a value of "PASS"
    RESULT_PASS = "PASS"

    def __init__(self, **kwargs):
        """
        Initializes a new AdvisorReport object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param report_location_details:
            The value to assign to the report_location_details property of this AdvisorReport.
        :type report_location_details: oci.database_migration.models.AdvisorReportLocationDetails

        :param result:
            The value to assign to the result property of this AdvisorReport.
            Allowed values for this property are: "FATAL", "BLOCKER", "WARNING", "INFORMATIONAL", "PASS", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type result: str

        :param number_of_fatal:
            The value to assign to the number_of_fatal property of this AdvisorReport.
        :type number_of_fatal: int

        :param number_of_fatal_blockers:
            The value to assign to the number_of_fatal_blockers property of this AdvisorReport.
        :type number_of_fatal_blockers: int

        :param number_of_warnings:
            The value to assign to the number_of_warnings property of this AdvisorReport.
        :type number_of_warnings: int

        :param number_of_informational_results:
            The value to assign to the number_of_informational_results property of this AdvisorReport.
        :type number_of_informational_results: int

        """
        self.swagger_types = {
            'report_location_details': 'AdvisorReportLocationDetails',
            'result': 'str',
            'number_of_fatal': 'int',
            'number_of_fatal_blockers': 'int',
            'number_of_warnings': 'int',
            'number_of_informational_results': 'int'
        }

        self.attribute_map = {
            'report_location_details': 'reportLocationDetails',
            'result': 'result',
            'number_of_fatal': 'numberOfFatal',
            'number_of_fatal_blockers': 'numberOfFatalBlockers',
            'number_of_warnings': 'numberOfWarnings',
            'number_of_informational_results': 'numberOfInformationalResults'
        }

        self._report_location_details = None
        self._result = None
        self._number_of_fatal = None
        self._number_of_fatal_blockers = None
        self._number_of_warnings = None
        self._number_of_informational_results = None

    @property
    def report_location_details(self):
        """
        Gets the report_location_details of this AdvisorReport.

        :return: The report_location_details of this AdvisorReport.
        :rtype: oci.database_migration.models.AdvisorReportLocationDetails
        """
        return self._report_location_details

    @report_location_details.setter
    def report_location_details(self, report_location_details):
        """
        Sets the report_location_details of this AdvisorReport.

        :param report_location_details: The report_location_details of this AdvisorReport.
        :type: oci.database_migration.models.AdvisorReportLocationDetails
        """
        self._report_location_details = report_location_details

    @property
    def result(self):
        """
        **[Required]** Gets the result of this AdvisorReport.
        Pre-Migration advisor result.

        Allowed values for this property are: "FATAL", "BLOCKER", "WARNING", "INFORMATIONAL", "PASS", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The result of this AdvisorReport.
        :rtype: str
        """
        return self._result

    @result.setter
    def result(self, result):
        """
        Sets the result of this AdvisorReport.
        Pre-Migration advisor result.


        :param result: The result of this AdvisorReport.
        :type: str
        """
        allowed_values = ["FATAL", "BLOCKER", "WARNING", "INFORMATIONAL", "PASS"]
        if not value_allowed_none_or_none_sentinel(result, allowed_values):
            result = 'UNKNOWN_ENUM_VALUE'
        self._result = result

    @property
    def number_of_fatal(self):
        """
        **[Required]** Gets the number_of_fatal of this AdvisorReport.
        Number of Fatal results in the advisor report.


        :return: The number_of_fatal of this AdvisorReport.
        :rtype: int
        """
        return self._number_of_fatal

    @number_of_fatal.setter
    def number_of_fatal(self, number_of_fatal):
        """
        Sets the number_of_fatal of this AdvisorReport.
        Number of Fatal results in the advisor report.


        :param number_of_fatal: The number_of_fatal of this AdvisorReport.
        :type: int
        """
        self._number_of_fatal = number_of_fatal

    @property
    def number_of_fatal_blockers(self):
        """
        **[Required]** Gets the number_of_fatal_blockers of this AdvisorReport.
        Number of Fatal Blocker results in the advisor report.


        :return: The number_of_fatal_blockers of this AdvisorReport.
        :rtype: int
        """
        return self._number_of_fatal_blockers

    @number_of_fatal_blockers.setter
    def number_of_fatal_blockers(self, number_of_fatal_blockers):
        """
        Sets the number_of_fatal_blockers of this AdvisorReport.
        Number of Fatal Blocker results in the advisor report.


        :param number_of_fatal_blockers: The number_of_fatal_blockers of this AdvisorReport.
        :type: int
        """
        self._number_of_fatal_blockers = number_of_fatal_blockers

    @property
    def number_of_warnings(self):
        """
        **[Required]** Gets the number_of_warnings of this AdvisorReport.
        Number of Warning results in the advisor report.


        :return: The number_of_warnings of this AdvisorReport.
        :rtype: int
        """
        return self._number_of_warnings

    @number_of_warnings.setter
    def number_of_warnings(self, number_of_warnings):
        """
        Sets the number_of_warnings of this AdvisorReport.
        Number of Warning results in the advisor report.


        :param number_of_warnings: The number_of_warnings of this AdvisorReport.
        :type: int
        """
        self._number_of_warnings = number_of_warnings

    @property
    def number_of_informational_results(self):
        """
        **[Required]** Gets the number_of_informational_results of this AdvisorReport.
        Number of Informational results in the advisor report.


        :return: The number_of_informational_results of this AdvisorReport.
        :rtype: int
        """
        return self._number_of_informational_results

    @number_of_informational_results.setter
    def number_of_informational_results(self, number_of_informational_results):
        """
        Sets the number_of_informational_results of this AdvisorReport.
        Number of Informational results in the advisor report.


        :param number_of_informational_results: The number_of_informational_results of this AdvisorReport.
        :type: int
        """
        self._number_of_informational_results = number_of_informational_results

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDataProfileDetails(object):
    """
    The data profile payload.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDataProfileDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param read_operation_config:
            The value to assign to the read_operation_config property of this CreateDataProfileDetails.
        :type read_operation_config: oci.data_connectivity.models.ReadOperationConfig

        :param data_asset:
            The value to assign to the data_asset property of this CreateDataProfileDetails.
        :type data_asset: oci.data_connectivity.models.DataAsset

        :param connection:
            The value to assign to the connection property of this CreateDataProfileDetails.
        :type connection: oci.data_connectivity.models.Connection

        :param schema:
            The value to assign to the schema property of this CreateDataProfileDetails.
        :type schema: oci.data_connectivity.models.Schema

        :param data_entity:
            The value to assign to the data_entity property of this CreateDataProfileDetails.
        :type data_entity: oci.data_connectivity.models.DataEntity

        :param profile_config:
            The value to assign to the profile_config property of this CreateDataProfileDetails.
        :type profile_config: oci.data_connectivity.models.ProfileConfig

        """
        self.swagger_types = {
            'read_operation_config': 'ReadOperationConfig',
            'data_asset': 'DataAsset',
            'connection': 'Connection',
            'schema': 'Schema',
            'data_entity': 'DataEntity',
            'profile_config': 'ProfileConfig'
        }

        self.attribute_map = {
            'read_operation_config': 'readOperationConfig',
            'data_asset': 'dataAsset',
            'connection': 'connection',
            'schema': 'schema',
            'data_entity': 'dataEntity',
            'profile_config': 'profileConfig'
        }

        self._read_operation_config = None
        self._data_asset = None
        self._connection = None
        self._schema = None
        self._data_entity = None
        self._profile_config = None

    @property
    def read_operation_config(self):
        """
        Gets the read_operation_config of this CreateDataProfileDetails.

        :return: The read_operation_config of this CreateDataProfileDetails.
        :rtype: oci.data_connectivity.models.ReadOperationConfig
        """
        return self._read_operation_config

    @read_operation_config.setter
    def read_operation_config(self, read_operation_config):
        """
        Sets the read_operation_config of this CreateDataProfileDetails.

        :param read_operation_config: The read_operation_config of this CreateDataProfileDetails.
        :type: oci.data_connectivity.models.ReadOperationConfig
        """
        self._read_operation_config = read_operation_config

    @property
    def data_asset(self):
        """
        Gets the data_asset of this CreateDataProfileDetails.

        :return: The data_asset of this CreateDataProfileDetails.
        :rtype: oci.data_connectivity.models.DataAsset
        """
        return self._data_asset

    @data_asset.setter
    def data_asset(self, data_asset):
        """
        Sets the data_asset of this CreateDataProfileDetails.

        :param data_asset: The data_asset of this CreateDataProfileDetails.
        :type: oci.data_connectivity.models.DataAsset
        """
        self._data_asset = data_asset

    @property
    def connection(self):
        """
        Gets the connection of this CreateDataProfileDetails.

        :return: The connection of this CreateDataProfileDetails.
        :rtype: oci.data_connectivity.models.Connection
        """
        return self._connection

    @connection.setter
    def connection(self, connection):
        """
        Sets the connection of this CreateDataProfileDetails.

        :param connection: The connection of this CreateDataProfileDetails.
        :type: oci.data_connectivity.models.Connection
        """
        self._connection = connection

    @property
    def schema(self):
        """
        Gets the schema of this CreateDataProfileDetails.

        :return: The schema of this CreateDataProfileDetails.
        :rtype: oci.data_connectivity.models.Schema
        """
        return self._schema

    @schema.setter
    def schema(self, schema):
        """
        Sets the schema of this CreateDataProfileDetails.

        :param schema: The schema of this CreateDataProfileDetails.
        :type: oci.data_connectivity.models.Schema
        """
        self._schema = schema

    @property
    def data_entity(self):
        """
        Gets the data_entity of this CreateDataProfileDetails.

        :return: The data_entity of this CreateDataProfileDetails.
        :rtype: oci.data_connectivity.models.DataEntity
        """
        return self._data_entity

    @data_entity.setter
    def data_entity(self, data_entity):
        """
        Sets the data_entity of this CreateDataProfileDetails.

        :param data_entity: The data_entity of this CreateDataProfileDetails.
        :type: oci.data_connectivity.models.DataEntity
        """
        self._data_entity = data_entity

    @property
    def profile_config(self):
        """
        Gets the profile_config of this CreateDataProfileDetails.

        :return: The profile_config of this CreateDataProfileDetails.
        :rtype: oci.data_connectivity.models.ProfileConfig
        """
        return self._profile_config

    @profile_config.setter
    def profile_config(self, profile_config):
        """
        Sets the profile_config of this CreateDataProfileDetails.

        :param profile_config: The profile_config of this CreateDataProfileDetails.
        :type: oci.data_connectivity.models.ProfileConfig
        """
        self._profile_config = profile_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class BuildPipelineParameter(object):
    """
    Parameter name for which the values will be supplied at the time of running the build.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new BuildPipelineParameter object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param name:
            The value to assign to the name property of this BuildPipelineParameter.
        :type name: str

        :param default_value:
            The value to assign to the default_value property of this BuildPipelineParameter.
        :type default_value: str

        :param description:
            The value to assign to the description property of this BuildPipelineParameter.
        :type description: str

        """
        self.swagger_types = {
            'name': 'str',
            'default_value': 'str',
            'description': 'str'
        }

        self.attribute_map = {
            'name': 'name',
            'default_value': 'defaultValue',
            'description': 'description'
        }

        self._name = None
        self._default_value = None
        self._description = None

    @property
    def name(self):
        """
        **[Required]** Gets the name of this BuildPipelineParameter.
        Name of the parameter (case-sensitive). Parameter name must be ^[a-zA-Z][a-zA-Z_0-9]*$.
        Example: 'Build_Pipeline_param' is not same as 'build_pipeline_Param'


        :return: The name of this BuildPipelineParameter.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this BuildPipelineParameter.
        Name of the parameter (case-sensitive). Parameter name must be ^[a-zA-Z][a-zA-Z_0-9]*$.
        Example: 'Build_Pipeline_param' is not same as 'build_pipeline_Param'


        :param name: The name of this BuildPipelineParameter.
        :type: str
        """
        self._name = name

    @property
    def default_value(self):
        """
        Gets the default_value of this BuildPipelineParameter.
        Default value of the parameter.


        :return: The default_value of this BuildPipelineParameter.
        :rtype: str
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """
        Sets the default_value of this BuildPipelineParameter.
        Default value of the parameter.


        :param default_value: The default_value of this BuildPipelineParameter.
        :type: str
        """
        self._default_value = default_value

    @property
    def description(self):
        """
        Gets the description of this BuildPipelineParameter.
        Description of the parameter.


        :return: The description of this BuildPipelineParameter.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this BuildPipelineParameter.
        Description of the parameter.


        :param description: The description of this BuildPipelineParameter.
        :type: str
        """
        self._description = description

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .add_em_managed_external_exadata_insight_members_details import AddEmManagedExternalExadataInsightMembersDetails
from .add_exadata_insight_members_details import AddExadataInsightMembersDetails
from .autonomous_database_configuration_summary import AutonomousDatabaseConfigurationSummary
from .autonomous_database_insight import AutonomousDatabaseInsight
from .autonomous_database_insight_summary import AutonomousDatabaseInsightSummary
from .awr_hub import AwrHub
from .awr_hub_summary import AwrHubSummary
from .awr_hub_summary_collection import AwrHubSummaryCollection
from .awr_hubs import AwrHubs
from .awr_report import AwrReport
from .awr_snapshot_collection import AwrSnapshotCollection
from .awr_snapshot_summary import AwrSnapshotSummary
from .awr_source_summary import AwrSourceSummary
from .change_database_insight_compartment_details import ChangeDatabaseInsightCompartmentDetails
from .change_enterprise_manager_bridge_compartment_details import ChangeEnterpriseManagerBridgeCompartmentDetails
from .change_exadata_insight_compartment_details import ChangeExadataInsightCompartmentDetails
from .change_host_insight_compartment_details import ChangeHostInsightCompartmentDetails
from .change_operations_insights_private_endpoint_compartment_details import ChangeOperationsInsightsPrivateEndpointCompartmentDetails
from .change_pe_comanaged_database_insight_details import ChangePeComanagedDatabaseInsightDetails
from .connection_details import ConnectionDetails
from .create_awr_hub_details import CreateAwrHubDetails
from .create_database_insight_details import CreateDatabaseInsightDetails
from .create_em_managed_external_database_insight_details import CreateEmManagedExternalDatabaseInsightDetails
from .create_em_managed_external_exadata_insight_details import CreateEmManagedExternalExadataInsightDetails
from .create_em_managed_external_exadata_member_entity_details import CreateEmManagedExternalExadataMemberEntityDetails
from .create_em_managed_external_host_insight_details import CreateEmManagedExternalHostInsightDetails
from .create_enterprise_manager_bridge_details import CreateEnterpriseManagerBridgeDetails
from .create_exadata_insight_details import CreateExadataInsightDetails
from .create_host_insight_details import CreateHostInsightDetails
from .create_macs_managed_external_host_insight_details import CreateMacsManagedExternalHostInsightDetails
from .create_operations_insights_private_endpoint_details import CreateOperationsInsightsPrivateEndpointDetails
from .create_operations_insights_warehouse_details import CreateOperationsInsightsWarehouseDetails
from .create_operations_insights_warehouse_user_details import CreateOperationsInsightsWarehouseUserDetails
from .create_pe_comanaged_database_insight_details import CreatePeComanagedDatabaseInsightDetails
from .credential_by_vault import CredentialByVault
from .credential_details import CredentialDetails
from .credentials_by_source import CredentialsBySource
from .db_external_instance import DBExternalInstance
from .db_external_properties import DBExternalProperties
from .dbos_config_instance import DBOSConfigInstance
from .data_object_column_metadata import DataObjectColumnMetadata
from .data_object_column_unit import DataObjectColumnUnit
from .data_object_core_column_unit import DataObjectCoreColumnUnit
from .data_object_custom_column_unit import DataObjectCustomColumnUnit
from .data_object_data_size_column_unit import DataObjectDataSizeColumnUnit
from .data_object_frequency_column_unit import DataObjectFrequencyColumnUnit
from .data_object_other_standard_column_unit import DataObjectOtherStandardColumnUnit
from .data_object_power_column_unit import DataObjectPowerColumnUnit
from .data_object_query import DataObjectQuery
from .data_object_query_time_filters import DataObjectQueryTimeFilters
from .data_object_rate_column_unit import DataObjectRateColumnUnit
from .data_object_temperature_column_unit import DataObjectTemperatureColumnUnit
from .data_object_templatized_query import DataObjectTemplatizedQuery
from .data_object_time_column_unit import DataObjectTimeColumnUnit
from .database_configuration_collection import DatabaseConfigurationCollection
from .database_configuration_metric_group import DatabaseConfigurationMetricGroup
from .database_configuration_summary import DatabaseConfigurationSummary
from .database_details import DatabaseDetails
from .database_insight import DatabaseInsight
from .database_insight_summary import DatabaseInsightSummary
from .database_insights import DatabaseInsights
from .database_insights_collection import DatabaseInsightsCollection
from .database_insights_data_object import DatabaseInsightsDataObject
from .database_insights_data_object_summary import DatabaseInsightsDataObjectSummary
from .disk_group_details import DiskGroupDetails
from .download_operations_insights_warehouse_wallet_details import DownloadOperationsInsightsWarehouseWalletDetails
from .em_managed_external_database_configuration_summary import EmManagedExternalDatabaseConfigurationSummary
from .em_managed_external_database_insight import EmManagedExternalDatabaseInsight
from .em_managed_external_database_insight_summary import EmManagedExternalDatabaseInsightSummary
from .em_managed_external_exadata_insight import EmManagedExternalExadataInsight
from .em_managed_external_exadata_insight_summary import EmManagedExternalExadataInsightSummary
from .em_managed_external_host_configuration_summary import EmManagedExternalHostConfigurationSummary
from .em_managed_external_host_insight import EmManagedExternalHostInsight
from .em_managed_external_host_insight_summary import EmManagedExternalHostInsightSummary
from .enable_database_insight_details import EnableDatabaseInsightDetails
from .enable_em_managed_external_database_insight_details import EnableEmManagedExternalDatabaseInsightDetails
from .enable_em_managed_external_exadata_insight_details import EnableEmManagedExternalExadataInsightDetails
from .enable_em_managed_external_host_insight_details import EnableEmManagedExternalHostInsightDetails
from .enable_exadata_insight_details import EnableExadataInsightDetails
from .enable_host_insight_details import EnableHostInsightDetails
from .enable_macs_managed_external_host_insight_details import EnableMacsManagedExternalHostInsightDetails
from .enable_pe_comanaged_database_insight_details import EnablePeComanagedDatabaseInsightDetails
from .enterprise_manager_bridge import EnterpriseManagerBridge
from .enterprise_manager_bridge_collection import EnterpriseManagerBridgeCollection
from .enterprise_manager_bridge_summary import EnterpriseManagerBridgeSummary
from .enterprise_manager_bridges import EnterpriseManagerBridges
from .exadata_configuration_collection import ExadataConfigurationCollection
from .exadata_configuration_summary import ExadataConfigurationSummary
from .exadata_database_machine_configuration_summary import ExadataDatabaseMachineConfigurationSummary
from .exadata_database_statistics_summary import ExadataDatabaseStatisticsSummary
from .exadata_details import ExadataDetails
from .exadata_diskgroup_statistics_summary import ExadataDiskgroupStatisticsSummary
from .exadata_host_statistics_summary import ExadataHostStatisticsSummary
from .exadata_insight import ExadataInsight
from .exadata_insight_resource_capacity_trend_aggregation import ExadataInsightResourceCapacityTrendAggregation
from .exadata_insight_resource_capacity_trend_summary import ExadataInsightResourceCapacityTrendSummary
from .exadata_insight_resource_forecast_trend_summary import ExadataInsightResourceForecastTrendSummary
from .exadata_insight_resource_insight_utilization_item import ExadataInsightResourceInsightUtilizationItem
from .exadata_insight_resource_statistics import ExadataInsightResourceStatistics
from .exadata_insight_resource_statistics_aggregation import ExadataInsightResourceStatisticsAggregation
from .exadata_insight_summary import ExadataInsightSummary
from .exadata_insight_summary_collection import ExadataInsightSummaryCollection
from .exadata_insights import ExadataInsights
from .exadata_insights_data_object import ExadataInsightsDataObject
from .exadata_insights_data_object_summary import ExadataInsightsDataObjectSummary
from .exadata_member_collection import ExadataMemberCollection
from .exadata_member_summary import ExadataMemberSummary
from .exadata_storage_server_statistics_summary import ExadataStorageServerStatisticsSummary
from .historical_data_item import HistoricalDataItem
from .host_configuration_collection import HostConfigurationCollection
from .host_configuration_metric_group import HostConfigurationMetricGroup
from .host_configuration_summary import HostConfigurationSummary
from .host_cpu_hardware_configuration import HostCpuHardwareConfiguration
from .host_cpu_statistics import HostCpuStatistics
from .host_cpu_usage import HostCpuUsage
from .host_details import HostDetails
from .host_entities import HostEntities
from .host_hardware_configuration import HostHardwareConfiguration
from .host_importable_agent_entity_summary import HostImportableAgentEntitySummary
from .host_insight import HostInsight
from .host_insight_resource_statistics_aggregation import HostInsightResourceStatisticsAggregation
from .host_insight_summary import HostInsightSummary
from .host_insight_summary_collection import HostInsightSummaryCollection
from .host_insights import HostInsights
from .host_insights_data_object import HostInsightsDataObject
from .host_insights_data_object_summary import HostInsightsDataObjectSummary
from .host_instance_map import HostInstanceMap
from .host_memory_configuration import HostMemoryConfiguration
from .host_memory_statistics import HostMemoryStatistics
from .host_memory_usage import HostMemoryUsage
from .host_network_activity_summary import HostNetworkActivitySummary
from .host_network_configuration import HostNetworkConfiguration
from .host_performance_metric_group import HostPerformanceMetricGroup
from .host_product import HostProduct
from .host_resource_allocation import HostResourceAllocation
from .host_resource_capacity_trend_aggregation import HostResourceCapacityTrendAggregation
from .host_resource_statistics import HostResourceStatistics
from .host_top_processes import HostTopProcesses
from .hosted_entity_collection import HostedEntityCollection
from .hosted_entity_summary import HostedEntitySummary
from .importable_agent_entity_summary import ImportableAgentEntitySummary
from .importable_agent_entity_summary_collection import ImportableAgentEntitySummaryCollection
from .importable_enterprise_manager_entity import ImportableEnterpriseManagerEntity
from .importable_enterprise_manager_entity_collection import ImportableEnterpriseManagerEntityCollection
from .ingest_database_configuration_details import IngestDatabaseConfigurationDetails
from .ingest_database_configuration_response_details import IngestDatabaseConfigurationResponseDetails
from .ingest_host_configuration_details import IngestHostConfigurationDetails
from .ingest_host_configuration_response_details import IngestHostConfigurationResponseDetails
from .ingest_host_metrics_details import IngestHostMetricsDetails
from .ingest_host_metrics_response_details import IngestHostMetricsResponseDetails
from .ingest_sql_bucket_details import IngestSqlBucketDetails
from .ingest_sql_bucket_response_details import IngestSqlBucketResponseDetails
from .ingest_sql_plan_lines_details import IngestSqlPlanLinesDetails
from .ingest_sql_plan_lines_response_details import IngestSqlPlanLinesResponseDetails
from .ingest_sql_stats_details import IngestSqlStatsDetails
from .ingest_sql_stats_response_details import IngestSqlStatsResponseDetails
from .ingest_sql_text_details import IngestSqlTextDetails
from .ingest_sql_text_response_details import IngestSqlTextResponseDetails
from .instance_metrics import InstanceMetrics
from .macs_managed_external_database_configuration_summary import MacsManagedExternalDatabaseConfigurationSummary
from .macs_managed_external_database_insight import MacsManagedExternalDatabaseInsight
from .macs_managed_external_database_insight_summary import MacsManagedExternalDatabaseInsightSummary
from .macs_managed_external_host_configuration_summary import MacsManagedExternalHostConfigurationSummary
from .macs_managed_external_host_insight import MacsManagedExternalHostInsight
from .macs_managed_external_host_insight_summary import MacsManagedExternalHostInsightSummary
from .operations_insights_private_endpoint import OperationsInsightsPrivateEndpoint
from .operations_insights_private_endpoint_collection import OperationsInsightsPrivateEndpointCollection
from .operations_insights_private_endpoint_summary import OperationsInsightsPrivateEndpointSummary
from .operations_insights_warehouse import OperationsInsightsWarehouse
from .operations_insights_warehouse_summary import OperationsInsightsWarehouseSummary
from .operations_insights_warehouse_summary_collection import OperationsInsightsWarehouseSummaryCollection
from .operations_insights_warehouse_user import OperationsInsightsWarehouseUser
from .operations_insights_warehouse_user_summary import OperationsInsightsWarehouseUserSummary
from .operations_insights_warehouse_user_summary_collection import OperationsInsightsWarehouseUserSummaryCollection
from .operations_insights_warehouse_users import OperationsInsightsWarehouseUsers
from .operations_insights_warehouses import OperationsInsightsWarehouses
from .opsi_data_object import OpsiDataObject
from .opsi_data_object_summary import OpsiDataObjectSummary
from .opsi_data_objects import OpsiDataObjects
from .opsi_data_objects_collection import OpsiDataObjectsCollection
from .pe_comanaged_database_connection_details import PeComanagedDatabaseConnectionDetails
from .pe_comanaged_database_host_details import PeComanagedDatabaseHostDetails
from .pe_comanaged_database_insight import PeComanagedDatabaseInsight
from .pe_comanaged_database_insight_summary import PeComanagedDatabaseInsightSummary
from .pe_comanaged_managed_external_database_configuration_summary import PeComanagedManagedExternalDatabaseConfigurationSummary
from .projected_data_item import ProjectedDataItem
from .query_data_object_json_result_set_rows_collection import QueryDataObjectJsonResultSetRowsCollection
from .query_data_object_result_set_column_metadata import QueryDataObjectResultSetColumnMetadata
from .query_data_object_result_set_rows_collection import QueryDataObjectResultSetRowsCollection
from .query_opsi_data_object_data_details import QueryOpsiDataObjectDataDetails
from .resource_capacity_trend_aggregation import ResourceCapacityTrendAggregation
from .resource_filters import ResourceFilters
from .resource_insight_current_utilization import ResourceInsightCurrentUtilization
from .resource_insight_projected_utilization import ResourceInsightProjectedUtilization
from .resource_insight_projected_utilization_item import ResourceInsightProjectedUtilizationItem
from .resource_statistics import ResourceStatistics
from .resource_statistics_aggregation import ResourceStatisticsAggregation
from .resource_usage_summary import ResourceUsageSummary
from .resource_usage_trend_aggregation import ResourceUsageTrendAggregation
from .sql_bucket import SqlBucket
from .sql_insight_aggregation import SqlInsightAggregation
from .sql_insight_aggregation_collection import SqlInsightAggregationCollection
from .sql_insight_thresholds import SqlInsightThresholds
from .sql_inventory import SqlInventory
from .sql_plan_collection import SqlPlanCollection
from .sql_plan_insight_aggregation import SqlPlanInsightAggregation
from .sql_plan_insight_aggregation_collection import SqlPlanInsightAggregationCollection
from .sql_plan_insights import SqlPlanInsights
from .sql_plan_line import SqlPlanLine
from .sql_plan_summary import SqlPlanSummary
from .sql_response_time_distribution_aggregation import SqlResponseTimeDistributionAggregation
from .sql_response_time_distribution_aggregation_collection import SqlResponseTimeDistributionAggregationCollection
from .sql_search_collection import SqlSearchCollection
from .sql_search_summary import SqlSearchSummary
from .sql_statistic_aggregation import SqlStatisticAggregation
from .sql_statistic_aggregation_collection import SqlStatisticAggregationCollection
from .sql_statistics import SqlStatistics
from .sql_statistics_time_series import SqlStatisticsTimeSeries
from .sql_statistics_time_series_aggregation import SqlStatisticsTimeSeriesAggregation
from .sql_statistics_time_series_aggregation_collection import SqlStatisticsTimeSeriesAggregationCollection
from .sql_statistics_time_series_by_plan_aggregation import SqlStatisticsTimeSeriesByPlanAggregation
from .sql_statistics_time_series_by_plan_aggregation_collection import SqlStatisticsTimeSeriesByPlanAggregationCollection
from .sql_stats import SqlStats
from .sql_text import SqlText
from .sql_text_collection import SqlTextCollection
from .sql_text_summary import SqlTextSummary
from .storage_server_details import StorageServerDetails
from .summarize_awr_sources_summaries_collection import SummarizeAwrSourcesSummariesCollection
from .summarize_database_insight_resource_capacity_trend_aggregation_collection import SummarizeDatabaseInsightResourceCapacityTrendAggregationCollection
from .summarize_database_insight_resource_forecast_trend_aggregation import SummarizeDatabaseInsightResourceForecastTrendAggregation
from .summarize_database_insight_resource_statistics_aggregation_collection import SummarizeDatabaseInsightResourceStatisticsAggregationCollection
from .summarize_database_insight_resource_usage_aggregation import SummarizeDatabaseInsightResourceUsageAggregation
from .summarize_database_insight_resource_usage_trend_aggregation_collection import SummarizeDatabaseInsightResourceUsageTrendAggregationCollection
from .summarize_database_insight_resource_utilization_insight_aggregation import SummarizeDatabaseInsightResourceUtilizationInsightAggregation
from .summarize_database_insight_tablespace_usage_trend_aggregation_collection import SummarizeDatabaseInsightTablespaceUsageTrendAggregationCollection
from .summarize_exadata_insight_resource_capacity_trend_aggregation import SummarizeExadataInsightResourceCapacityTrendAggregation
from .summarize_exadata_insight_resource_capacity_trend_collection import SummarizeExadataInsightResourceCapacityTrendCollection
from .summarize_exadata_insight_resource_forecast_trend_aggregation import SummarizeExadataInsightResourceForecastTrendAggregation
from .summarize_exadata_insight_resource_forecast_trend_collection import SummarizeExadataInsightResourceForecastTrendCollection
from .summarize_exadata_insight_resource_statistics_aggregation_collection import SummarizeExadataInsightResourceStatisticsAggregationCollection
from .summarize_exadata_insight_resource_usage_aggregation import SummarizeExadataInsightResourceUsageAggregation
from .summarize_exadata_insight_resource_usage_collection import SummarizeExadataInsightResourceUsageCollection
from .summarize_exadata_insight_resource_utilization_insight_aggregation import SummarizeExadataInsightResourceUtilizationInsightAggregation
from .summarize_host_insight_resource_capacity_trend_aggregation_collection import SummarizeHostInsightResourceCapacityTrendAggregationCollection
from .summarize_host_insight_resource_forecast_trend_aggregation import SummarizeHostInsightResourceForecastTrendAggregation
from .summarize_host_insight_resource_statistics_aggregation_collection import SummarizeHostInsightResourceStatisticsAggregationCollection
from .summarize_host_insight_resource_usage_aggregation import SummarizeHostInsightResourceUsageAggregation
from .summarize_host_insight_resource_usage_trend_aggregation_collection import SummarizeHostInsightResourceUsageTrendAggregationCollection
from .summarize_host_insight_resource_utilization_insight_aggregation import SummarizeHostInsightResourceUtilizationInsightAggregation
from .summarize_host_insights_top_processes_usage_trend_collection import SummarizeHostInsightsTopProcessesUsageTrendCollection
from .summarize_operations_insights_warehouse_resource_usage_aggregation import SummarizeOperationsInsightsWarehouseResourceUsageAggregation
from .summary_statistics import SummaryStatistics
from .tablespace_usage_trend import TablespaceUsageTrend
from .tablespace_usage_trend_aggregation import TablespaceUsageTrendAggregation
from .top_processes_usage_trend import TopProcessesUsageTrend
from .top_processes_usage_trend_aggregation import TopProcessesUsageTrendAggregation
from .update_autonomous_database_insight_details import UpdateAutonomousDatabaseInsightDetails
from .update_awr_hub_details import UpdateAwrHubDetails
from .update_database_insight_details import UpdateDatabaseInsightDetails
from .update_em_managed_external_database_insight_details import UpdateEmManagedExternalDatabaseInsightDetails
from .update_em_managed_external_exadata_insight_details import UpdateEmManagedExternalExadataInsightDetails
from .update_em_managed_external_host_insight_details import UpdateEmManagedExternalHostInsightDetails
from .update_enterprise_manager_bridge_details import UpdateEnterpriseManagerBridgeDetails
from .update_exadata_insight_details import UpdateExadataInsightDetails
from .update_host_insight_details import UpdateHostInsightDetails
from .update_macs_managed_external_database_insight_details import UpdateMacsManagedExternalDatabaseInsightDetails
from .update_macs_managed_external_host_insight_details import UpdateMacsManagedExternalHostInsightDetails
from .update_operations_insights_private_endpoint_details import UpdateOperationsInsightsPrivateEndpointDetails
from .update_operations_insights_warehouse_details import UpdateOperationsInsightsWarehouseDetails
from .update_operations_insights_warehouse_user_details import UpdateOperationsInsightsWarehouseUserDetails
from .update_pe_comanaged_database_insight_details import UpdatePeComanagedDatabaseInsightDetails
from .work_request import WorkRequest
from .work_request_collection import WorkRequestCollection
from .work_request_error import WorkRequestError
from .work_request_error_collection import WorkRequestErrorCollection
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_log_entry_collection import WorkRequestLogEntryCollection
from .work_request_resource import WorkRequestResource
from .work_requests import WorkRequests

# Maps type names to classes for opsi services.
opsi_type_mapping = {
    "AddEmManagedExternalExadataInsightMembersDetails": AddEmManagedExternalExadataInsightMembersDetails,
    "AddExadataInsightMembersDetails": AddExadataInsightMembersDetails,
    "AutonomousDatabaseConfigurationSummary": AutonomousDatabaseConfigurationSummary,
    "AutonomousDatabaseInsight": AutonomousDatabaseInsight,
    "AutonomousDatabaseInsightSummary": AutonomousDatabaseInsightSummary,
    "AwrHub": AwrHub,
    "AwrHubSummary": AwrHubSummary,
    "AwrHubSummaryCollection": AwrHubSummaryCollection,
    "AwrHubs": AwrHubs,
    "AwrReport": AwrReport,
    "AwrSnapshotCollection": AwrSnapshotCollection,
    "AwrSnapshotSummary": AwrSnapshotSummary,
    "AwrSourceSummary": AwrSourceSummary,
    "ChangeDatabaseInsightCompartmentDetails": ChangeDatabaseInsightCompartmentDetails,
    "ChangeEnterpriseManagerBridgeCompartmentDetails": ChangeEnterpriseManagerBridgeCompartmentDetails,
    "ChangeExadataInsightCompartmentDetails": ChangeExadataInsightCompartmentDetails,
    "ChangeHostInsightCompartmentDetails": ChangeHostInsightCompartmentDetails,
    "ChangeOperationsInsightsPrivateEndpointCompartmentDetails": ChangeOperationsInsightsPrivateEndpointCompartmentDetails,
    "ChangePeComanagedDatabaseInsightDetails": ChangePeComanagedDatabaseInsightDetails,
    "ConnectionDetails": ConnectionDetails,
    "CreateAwrHubDetails": CreateAwrHubDetails,
    "CreateDatabaseInsightDetails": CreateDatabaseInsightDetails,
    "CreateEmManagedExternalDatabaseInsightDetails": CreateEmManagedExternalDatabaseInsightDetails,
    "CreateEmManagedExternalExadataInsightDetails": CreateEmManagedExternalExadataInsightDetails,
    "CreateEmManagedExternalExadataMemberEntityDetails": CreateEmManagedExternalExadataMemberEntityDetails,
    "CreateEmManagedExternalHostInsightDetails": CreateEmManagedExternalHostInsightDetails,
    "CreateEnterpriseManagerBridgeDetails": CreateEnterpriseManagerBridgeDetails,
    "CreateExadataInsightDetails": CreateExadataInsightDetails,
    "CreateHostInsightDetails": CreateHostInsightDetails,
    "CreateMacsManagedExternalHostInsightDetails": CreateMacsManagedExternalHostInsightDetails,
    "CreateOperationsInsightsPrivateEndpointDetails": CreateOperationsInsightsPrivateEndpointDetails,
    "CreateOperationsInsightsWarehouseDetails": CreateOperationsInsightsWarehouseDetails,
    "CreateOperationsInsightsWarehouseUserDetails": CreateOperationsInsightsWarehouseUserDetails,
    "CreatePeComanagedDatabaseInsightDetails": CreatePeComanagedDatabaseInsightDetails,
    "CredentialByVault": CredentialByVault,
    "CredentialDetails": CredentialDetails,
    "CredentialsBySource": CredentialsBySource,
    "DBExternalInstance": DBExternalInstance,
    "DBExternalProperties": DBExternalProperties,
    "DBOSConfigInstance": DBOSConfigInstance,
    "DataObjectColumnMetadata": DataObjectColumnMetadata,
    "DataObjectColumnUnit": DataObjectColumnUnit,
    "DataObjectCoreColumnUnit": DataObjectCoreColumnUnit,
    "DataObjectCustomColumnUnit": DataObjectCustomColumnUnit,
    "DataObjectDataSizeColumnUnit": DataObjectDataSizeColumnUnit,
    "DataObjectFrequencyColumnUnit": DataObjectFrequencyColumnUnit,
    "DataObjectOtherStandardColumnUnit": DataObjectOtherStandardColumnUnit,
    "DataObjectPowerColumnUnit": DataObjectPowerColumnUnit,
    "DataObjectQuery": DataObjectQuery,
    "DataObjectQueryTimeFilters": DataObjectQueryTimeFilters,
    "DataObjectRateColumnUnit": DataObjectRateColumnUnit,
    "DataObjectTemperatureColumnUnit": DataObjectTemperatureColumnUnit,
    "DataObjectTemplatizedQuery": DataObjectTemplatizedQuery,
    "DataObjectTimeColumnUnit": DataObjectTimeColumnUnit,
    "DatabaseConfigurationCollection": DatabaseConfigurationCollection,
    "DatabaseConfigurationMetricGroup": DatabaseConfigurationMetricGroup,
    "DatabaseConfigurationSummary": DatabaseConfigurationSummary,
    "DatabaseDetails": DatabaseDetails,
    "DatabaseInsight": DatabaseInsight,
    "DatabaseInsightSummary": DatabaseInsightSummary,
    "DatabaseInsights": DatabaseInsights,
    "DatabaseInsightsCollection": DatabaseInsightsCollection,
    "DatabaseInsightsDataObject": DatabaseInsightsDataObject,
    "DatabaseInsightsDataObjectSummary": DatabaseInsightsDataObjectSummary,
    "DiskGroupDetails": DiskGroupDetails,
    "DownloadOperationsInsightsWarehouseWalletDetails": DownloadOperationsInsightsWarehouseWalletDetails,
    "EmManagedExternalDatabaseConfigurationSummary": EmManagedExternalDatabaseConfigurationSummary,
    "EmManagedExternalDatabaseInsight": EmManagedExternalDatabaseInsight,
    "EmManagedExternalDatabaseInsightSummary": EmManagedExternalDatabaseInsightSummary,
    "EmManagedExternalExadataInsight": EmManagedExternalExadataInsight,
    "EmManagedExternalExadataInsightSummary": EmManagedExternalExadataInsightSummary,
    "EmManagedExternalHostConfigurationSummary": EmManagedExternalHostConfigurationSummary,
    "EmManagedExternalHostInsight": EmManagedExternalHostInsight,
    "EmManagedExternalHostInsightSummary": EmManagedExternalHostInsightSummary,
    "EnableDatabaseInsightDetails": EnableDatabaseInsightDetails,
    "EnableEmManagedExternalDatabaseInsightDetails": EnableEmManagedExternalDatabaseInsightDetails,
    "EnableEmManagedExternalExadataInsightDetails": EnableEmManagedExternalExadataInsightDetails,
    "EnableEmManagedExternalHostInsightDetails": EnableEmManagedExternalHostInsightDetails,
    "EnableExadataInsightDetails": EnableExadataInsightDetails,
    "EnableHostInsightDetails": EnableHostInsightDetails,
    "EnableMacsManagedExternalHostInsightDetails": EnableMacsManagedExternalHostInsightDetails,
    "EnablePeComanagedDatabaseInsightDetails": EnablePeComanagedDatabaseInsightDetails,
    "EnterpriseManagerBridge": EnterpriseManagerBridge,
    "EnterpriseManagerBridgeCollection": EnterpriseManagerBridgeCollection,
    "EnterpriseManagerBridgeSummary": EnterpriseManagerBridgeSummary,
    "EnterpriseManagerBridges": EnterpriseManagerBridges,
    "ExadataConfigurationCollection": ExadataConfigurationCollection,
    "ExadataConfigurationSummary": ExadataConfigurationSummary,
    "ExadataDatabaseMachineConfigurationSummary": ExadataDatabaseMachineConfigurationSummary,
    "ExadataDatabaseStatisticsSummary": ExadataDatabaseStatisticsSummary,
    "ExadataDetails": ExadataDetails,
    "ExadataDiskgroupStatisticsSummary": ExadataDiskgroupStatisticsSummary,
    "ExadataHostStatisticsSummary": ExadataHostStatisticsSummary,
    "ExadataInsight": ExadataInsight,
    "ExadataInsightResourceCapacityTrendAggregation": ExadataInsightResourceCapacityTrendAggregation,
    "ExadataInsightResourceCapacityTrendSummary": ExadataInsightResourceCapacityTrendSummary,
    "ExadataInsightResourceForecastTrendSummary": ExadataInsightResourceForecastTrendSummary,
    "ExadataInsightResourceInsightUtilizationItem": ExadataInsightResourceInsightUtilizationItem,
    "ExadataInsightResourceStatistics": ExadataInsightResourceStatistics,
    "ExadataInsightResourceStatisticsAggregation": ExadataInsightResourceStatisticsAggregation,
    "ExadataInsightSummary": ExadataInsightSummary,
    "ExadataInsightSummaryCollection": ExadataInsightSummaryCollection,
    "ExadataInsights": ExadataInsights,
    "ExadataInsightsDataObject": ExadataInsightsDataObject,
    "ExadataInsightsDataObjectSummary": ExadataInsightsDataObjectSummary,
    "ExadataMemberCollection": ExadataMemberCollection,
    "ExadataMemberSummary": ExadataMemberSummary,
    "ExadataStorageServerStatisticsSummary": ExadataStorageServerStatisticsSummary,
    "HistoricalDataItem": HistoricalDataItem,
    "HostConfigurationCollection": HostConfigurationCollection,
    "HostConfigurationMetricGroup": HostConfigurationMetricGroup,
    "HostConfigurationSummary": HostConfigurationSummary,
    "HostCpuHardwareConfiguration": HostCpuHardwareConfiguration,
    "HostCpuStatistics": HostCpuStatistics,
    "HostCpuUsage": HostCpuUsage,
    "HostDetails": HostDetails,
    "HostEntities": HostEntities,
    "HostHardwareConfiguration": HostHardwareConfiguration,
    "HostImportableAgentEntitySummary": HostImportableAgentEntitySummary,
    "HostInsight": HostInsight,
    "HostInsightResourceStatisticsAggregation": HostInsightResourceStatisticsAggregation,
    "HostInsightSummary": HostInsightSummary,
    "HostInsightSummaryCollection": HostInsightSummaryCollection,
    "HostInsights": HostInsights,
    "HostInsightsDataObject": HostInsightsDataObject,
    "HostInsightsDataObjectSummary": HostInsightsDataObjectSummary,
    "HostInstanceMap": HostInstanceMap,
    "HostMemoryConfiguration": HostMemoryConfiguration,
    "HostMemoryStatistics": HostMemoryStatistics,
    "HostMemoryUsage": HostMemoryUsage,
    "HostNetworkActivitySummary": HostNetworkActivitySummary,
    "HostNetworkConfiguration": HostNetworkConfiguration,
    "HostPerformanceMetricGroup": HostPerformanceMetricGroup,
    "HostProduct": HostProduct,
    "HostResourceAllocation": HostResourceAllocation,
    "HostResourceCapacityTrendAggregation": HostResourceCapacityTrendAggregation,
    "HostResourceStatistics": HostResourceStatistics,
    "HostTopProcesses": HostTopProcesses,
    "HostedEntityCollection": HostedEntityCollection,
    "HostedEntitySummary": HostedEntitySummary,
    "ImportableAgentEntitySummary": ImportableAgentEntitySummary,
    "ImportableAgentEntitySummaryCollection": ImportableAgentEntitySummaryCollection,
    "ImportableEnterpriseManagerEntity": ImportableEnterpriseManagerEntity,
    "ImportableEnterpriseManagerEntityCollection": ImportableEnterpriseManagerEntityCollection,
    "IngestDatabaseConfigurationDetails": IngestDatabaseConfigurationDetails,
    "IngestDatabaseConfigurationResponseDetails": IngestDatabaseConfigurationResponseDetails,
    "IngestHostConfigurationDetails": IngestHostConfigurationDetails,
    "IngestHostConfigurationResponseDetails": IngestHostConfigurationResponseDetails,
    "IngestHostMetricsDetails": IngestHostMetricsDetails,
    "IngestHostMetricsResponseDetails": IngestHostMetricsResponseDetails,
    "IngestSqlBucketDetails": IngestSqlBucketDetails,
    "IngestSqlBucketResponseDetails": IngestSqlBucketResponseDetails,
    "IngestSqlPlanLinesDetails": IngestSqlPlanLinesDetails,
    "IngestSqlPlanLinesResponseDetails": IngestSqlPlanLinesResponseDetails,
    "IngestSqlStatsDetails": IngestSqlStatsDetails,
    "IngestSqlStatsResponseDetails": IngestSqlStatsResponseDetails,
    "IngestSqlTextDetails": IngestSqlTextDetails,
    "IngestSqlTextResponseDetails": IngestSqlTextResponseDetails,
    "InstanceMetrics": InstanceMetrics,
    "MacsManagedExternalDatabaseConfigurationSummary": MacsManagedExternalDatabaseConfigurationSummary,
    "MacsManagedExternalDatabaseInsight": MacsManagedExternalDatabaseInsight,
    "MacsManagedExternalDatabaseInsightSummary": MacsManagedExternalDatabaseInsightSummary,
    "MacsManagedExternalHostConfigurationSummary": MacsManagedExternalHostConfigurationSummary,
    "MacsManagedExternalHostInsight": MacsManagedExternalHostInsight,
    "MacsManagedExternalHostInsightSummary": MacsManagedExternalHostInsightSummary,
    "OperationsInsightsPrivateEndpoint": OperationsInsightsPrivateEndpoint,
    "OperationsInsightsPrivateEndpointCollection": OperationsInsightsPrivateEndpointCollection,
    "OperationsInsightsPrivateEndpointSummary": OperationsInsightsPrivateEndpointSummary,
    "OperationsInsightsWarehouse": OperationsInsightsWarehouse,
    "OperationsInsightsWarehouseSummary": OperationsInsightsWarehouseSummary,
    "OperationsInsightsWarehouseSummaryCollection": OperationsInsightsWarehouseSummaryCollection,
    "OperationsInsightsWarehouseUser": OperationsInsightsWarehouseUser,
    "OperationsInsightsWarehouseUserSummary": OperationsInsightsWarehouseUserSummary,
    "OperationsInsightsWarehouseUserSummaryCollection": OperationsInsightsWarehouseUserSummaryCollection,
    "OperationsInsightsWarehouseUsers": OperationsInsightsWarehouseUsers,
    "OperationsInsightsWarehouses": OperationsInsightsWarehouses,
    "OpsiDataObject": OpsiDataObject,
    "OpsiDataObjectSummary": OpsiDataObjectSummary,
    "OpsiDataObjects": OpsiDataObjects,
    "OpsiDataObjectsCollection": OpsiDataObjectsCollection,
    "PeComanagedDatabaseConnectionDetails": PeComanagedDatabaseConnectionDetails,
    "PeComanagedDatabaseHostDetails": PeComanagedDatabaseHostDetails,
    "PeComanagedDatabaseInsight": PeComanagedDatabaseInsight,
    "PeComanagedDatabaseInsightSummary": PeComanagedDatabaseInsightSummary,
    "PeComanagedManagedExternalDatabaseConfigurationSummary": PeComanagedManagedExternalDatabaseConfigurationSummary,
    "ProjectedDataItem": ProjectedDataItem,
    "QueryDataObjectJsonResultSetRowsCollection": QueryDataObjectJsonResultSetRowsCollection,
    "QueryDataObjectResultSetColumnMetadata": QueryDataObjectResultSetColumnMetadata,
    "QueryDataObjectResultSetRowsCollection": QueryDataObjectResultSetRowsCollection,
    "QueryOpsiDataObjectDataDetails": QueryOpsiDataObjectDataDetails,
    "ResourceCapacityTrendAggregation": ResourceCapacityTrendAggregation,
    "ResourceFilters": ResourceFilters,
    "ResourceInsightCurrentUtilization": ResourceInsightCurrentUtilization,
    "ResourceInsightProjectedUtilization": ResourceInsightProjectedUtilization,
    "ResourceInsightProjectedUtilizationItem": ResourceInsightProjectedUtilizationItem,
    "ResourceStatistics": ResourceStatistics,
    "ResourceStatisticsAggregation": ResourceStatisticsAggregation,
    "ResourceUsageSummary": ResourceUsageSummary,
    "ResourceUsageTrendAggregation": ResourceUsageTrendAggregation,
    "SqlBucket": SqlBucket,
    "SqlInsightAggregation": SqlInsightAggregation,
    "SqlInsightAggregationCollection": SqlInsightAggregationCollection,
    "SqlInsightThresholds": SqlInsightThresholds,
    "SqlInventory": SqlInventory,
    "SqlPlanCollection": SqlPlanCollection,
    "SqlPlanInsightAggregation": SqlPlanInsightAggregation,
    "SqlPlanInsightAggregationCollection": SqlPlanInsightAggregationCollection,
    "SqlPlanInsights": SqlPlanInsights,
    "SqlPlanLine": SqlPlanLine,
    "SqlPlanSummary": SqlPlanSummary,
    "SqlResponseTimeDistributionAggregation": SqlResponseTimeDistributionAggregation,
    "SqlResponseTimeDistributionAggregationCollection": SqlResponseTimeDistributionAggregationCollection,
    "SqlSearchCollection": SqlSearchCollection,
    "SqlSearchSummary": SqlSearchSummary,
    "SqlStatisticAggregation": SqlStatisticAggregation,
    "SqlStatisticAggregationCollection": SqlStatisticAggregationCollection,
    "SqlStatistics": SqlStatistics,
    "SqlStatisticsTimeSeries": SqlStatisticsTimeSeries,
    "SqlStatisticsTimeSeriesAggregation": SqlStatisticsTimeSeriesAggregation,
    "SqlStatisticsTimeSeriesAggregationCollection": SqlStatisticsTimeSeriesAggregationCollection,
    "SqlStatisticsTimeSeriesByPlanAggregation": SqlStatisticsTimeSeriesByPlanAggregation,
    "SqlStatisticsTimeSeriesByPlanAggregationCollection": SqlStatisticsTimeSeriesByPlanAggregationCollection,
    "SqlStats": SqlStats,
    "SqlText": SqlText,
    "SqlTextCollection": SqlTextCollection,
    "SqlTextSummary": SqlTextSummary,
    "StorageServerDetails": StorageServerDetails,
    "SummarizeAwrSourcesSummariesCollection": SummarizeAwrSourcesSummariesCollection,
    "SummarizeDatabaseInsightResourceCapacityTrendAggregationCollection": SummarizeDatabaseInsightResourceCapacityTrendAggregationCollection,
    "SummarizeDatabaseInsightResourceForecastTrendAggregation": SummarizeDatabaseInsightResourceForecastTrendAggregation,
    "SummarizeDatabaseInsightResourceStatisticsAggregationCollection": SummarizeDatabaseInsightResourceStatisticsAggregationCollection,
    "SummarizeDatabaseInsightResourceUsageAggregation": SummarizeDatabaseInsightResourceUsageAggregation,
    "SummarizeDatabaseInsightResourceUsageTrendAggregationCollection": SummarizeDatabaseInsightResourceUsageTrendAggregationCollection,
    "SummarizeDatabaseInsightResourceUtilizationInsightAggregation": SummarizeDatabaseInsightResourceUtilizationInsightAggregation,
    "SummarizeDatabaseInsightTablespaceUsageTrendAggregationCollection": SummarizeDatabaseInsightTablespaceUsageTrendAggregationCollection,
    "SummarizeExadataInsightResourceCapacityTrendAggregation": SummarizeExadataInsightResourceCapacityTrendAggregation,
    "SummarizeExadataInsightResourceCapacityTrendCollection": SummarizeExadataInsightResourceCapacityTrendCollection,
    "SummarizeExadataInsightResourceForecastTrendAggregation": SummarizeExadataInsightResourceForecastTrendAggregation,
    "SummarizeExadataInsightResourceForecastTrendCollection": SummarizeExadataInsightResourceForecastTrendCollection,
    "SummarizeExadataInsightResourceStatisticsAggregationCollection": SummarizeExadataInsightResourceStatisticsAggregationCollection,
    "SummarizeExadataInsightResourceUsageAggregation": SummarizeExadataInsightResourceUsageAggregation,
    "SummarizeExadataInsightResourceUsageCollection": SummarizeExadataInsightResourceUsageCollection,
    "SummarizeExadataInsightResourceUtilizationInsightAggregation": SummarizeExadataInsightResourceUtilizationInsightAggregation,
    "SummarizeHostInsightResourceCapacityTrendAggregationCollection": SummarizeHostInsightResourceCapacityTrendAggregationCollection,
    "SummarizeHostInsightResourceForecastTrendAggregation": SummarizeHostInsightResourceForecastTrendAggregation,
    "SummarizeHostInsightResourceStatisticsAggregationCollection": SummarizeHostInsightResourceStatisticsAggregationCollection,
    "SummarizeHostInsightResourceUsageAggregation": SummarizeHostInsightResourceUsageAggregation,
    "SummarizeHostInsightResourceUsageTrendAggregationCollection": SummarizeHostInsightResourceUsageTrendAggregationCollection,
    "SummarizeHostInsightResourceUtilizationInsightAggregation": SummarizeHostInsightResourceUtilizationInsightAggregation,
    "SummarizeHostInsightsTopProcessesUsageTrendCollection": SummarizeHostInsightsTopProcessesUsageTrendCollection,
    "SummarizeOperationsInsightsWarehouseResourceUsageAggregation": SummarizeOperationsInsightsWarehouseResourceUsageAggregation,
    "SummaryStatistics": SummaryStatistics,
    "TablespaceUsageTrend": TablespaceUsageTrend,
    "TablespaceUsageTrendAggregation": TablespaceUsageTrendAggregation,
    "TopProcessesUsageTrend": TopProcessesUsageTrend,
    "TopProcessesUsageTrendAggregation": TopProcessesUsageTrendAggregation,
    "UpdateAutonomousDatabaseInsightDetails": UpdateAutonomousDatabaseInsightDetails,
    "UpdateAwrHubDetails": UpdateAwrHubDetails,
    "UpdateDatabaseInsightDetails": UpdateDatabaseInsightDetails,
    "UpdateEmManagedExternalDatabaseInsightDetails": UpdateEmManagedExternalDatabaseInsightDetails,
    "UpdateEmManagedExternalExadataInsightDetails": UpdateEmManagedExternalExadataInsightDetails,
    "UpdateEmManagedExternalHostInsightDetails": UpdateEmManagedExternalHostInsightDetails,
    "UpdateEnterpriseManagerBridgeDetails": UpdateEnterpriseManagerBridgeDetails,
    "UpdateExadataInsightDetails": UpdateExadataInsightDetails,
    "UpdateHostInsightDetails": UpdateHostInsightDetails,
    "UpdateMacsManagedExternalDatabaseInsightDetails": UpdateMacsManagedExternalDatabaseInsightDetails,
    "UpdateMacsManagedExternalHostInsightDetails": UpdateMacsManagedExternalHostInsightDetails,
    "UpdateOperationsInsightsPrivateEndpointDetails": UpdateOperationsInsightsPrivateEndpointDetails,
    "UpdateOperationsInsightsWarehouseDetails": UpdateOperationsInsightsWarehouseDetails,
    "UpdateOperationsInsightsWarehouseUserDetails": UpdateOperationsInsightsWarehouseUserDetails,
    "UpdatePeComanagedDatabaseInsightDetails": UpdatePeComanagedDatabaseInsightDetails,
    "WorkRequest": WorkRequest,
    "WorkRequestCollection": WorkRequestCollection,
    "WorkRequestError": WorkRequestError,
    "WorkRequestErrorCollection": WorkRequestErrorCollection,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestLogEntryCollection": WorkRequestLogEntryCollection,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequests": WorkRequests
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class VanityUrlDetails(object):
    """
    Vanity url configuration details.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new VanityUrlDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this VanityUrlDetails.
        :type key: str

        :param description:
            The value to assign to the description property of this VanityUrlDetails.
        :type description: str

        :param urls:
            The value to assign to the urls property of this VanityUrlDetails.
        :type urls: list[str]

        :param hosts:
            The value to assign to the hosts property of this VanityUrlDetails.
        :type hosts: list[str]

        :param public_certificate:
            The value to assign to the public_certificate property of this VanityUrlDetails.
        :type public_certificate: str

        """
        self.swagger_types = {
            'key': 'str',
            'description': 'str',
            'urls': 'list[str]',
            'hosts': 'list[str]',
            'public_certificate': 'str'
        }

        self.attribute_map = {
            'key': 'key',
            'description': 'description',
            'urls': 'urls',
            'hosts': 'hosts',
            'public_certificate': 'publicCertificate'
        }

        self._key = None
        self._description = None
        self._urls = None
        self._hosts = None
        self._public_certificate = None

    @property
    def key(self):
        """
        Gets the key of this VanityUrlDetails.
        The vanity url unique identifier key.


        :return: The key of this VanityUrlDetails.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this VanityUrlDetails.
        The vanity url unique identifier key.


        :param key: The key of this VanityUrlDetails.
        :type: str
        """
        self._key = key

    @property
    def description(self):
        """
        Gets the description of this VanityUrlDetails.
        Description of the vanity url.


        :return: The description of this VanityUrlDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this VanityUrlDetails.
        Description of the vanity url.


        :param description: The description of this VanityUrlDetails.
        :type: str
        """
        self._description = description

    @property
    def urls(self):
        """
        Gets the urls of this VanityUrlDetails.
        List of urls supported by this vanity URL definition (max of 3).


        :return: The urls of this VanityUrlDetails.
        :rtype: list[str]
        """
        return self._urls

    @urls.setter
    def urls(self, urls):
        """
        Sets the urls of this VanityUrlDetails.
        List of urls supported by this vanity URL definition (max of 3).


        :param urls: The urls of this VanityUrlDetails.
        :type: list[str]
        """
        self._urls = urls

    @property
    def hosts(self):
        """
        Gets the hosts of this VanityUrlDetails.
        List of fully qualified hostnames supported by this vanity URL definition (max of 3).


        :return: The hosts of this VanityUrlDetails.
        :rtype: list[str]
        """
        return self._hosts

    @hosts.setter
    def hosts(self, hosts):
        """
        Sets the hosts of this VanityUrlDetails.
        List of fully qualified hostnames supported by this vanity URL definition (max of 3).


        :param hosts: The hosts of this VanityUrlDetails.
        :type: list[str]
        """
        self._hosts = hosts

    @property
    def public_certificate(self):
        """
        Gets the public_certificate of this VanityUrlDetails.
        PEM certificate for HTTPS connections.


        :return: The public_certificate of this VanityUrlDetails.
        :rtype: str
        """
        return self._public_certificate

    @public_certificate.setter
    def public_certificate(self, public_certificate):
        """
        Sets the public_certificate of this VanityUrlDetails.
        PEM certificate for HTTPS connections.


        :param public_certificate: The public_certificate of this VanityUrlDetails.
        :type: str
        """
        self._public_certificate = public_certificate

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .database_tools_user_password_details import DatabaseToolsUserPasswordDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DatabaseToolsUserPasswordSecretIdDetails(DatabaseToolsUserPasswordDetails):
    """
    The user password.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DatabaseToolsUserPasswordSecretIdDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.database_tools.models.DatabaseToolsUserPasswordSecretIdDetails.value_type` attribute
        of this class is ``SECRETID`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param value_type:
            The value to assign to the value_type property of this DatabaseToolsUserPasswordSecretIdDetails.
            Allowed values for this property are: "SECRETID"
        :type value_type: str

        :param secret_id:
            The value to assign to the secret_id property of this DatabaseToolsUserPasswordSecretIdDetails.
        :type secret_id: str

        """
        self.swagger_types = {
            'value_type': 'str',
            'secret_id': 'str'
        }

        self.attribute_map = {
            'value_type': 'valueType',
            'secret_id': 'secretId'
        }

        self._value_type = None
        self._secret_id = None
        self._value_type = 'SECRETID'

    @property
    def secret_id(self):
        """
        Gets the secret_id of this DatabaseToolsUserPasswordSecretIdDetails.
        The `OCID`__ of the secret containing the user password.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The secret_id of this DatabaseToolsUserPasswordSecretIdDetails.
        :rtype: str
        """
        return self._secret_id

    @secret_id.setter
    def secret_id(self, secret_id):
        """
        Sets the secret_id of this DatabaseToolsUserPasswordSecretIdDetails.
        The `OCID`__ of the secret containing the user password.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param secret_id: The secret_id of this DatabaseToolsUserPasswordSecretIdDetails.
        :type: str
        """
        self._secret_id = secret_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Entity(object):
    """
    An entity allows the labeler to identify an object in the record to label.  This can be, for example, a snippet of text, an entire image, or a bounding box within an image.  All entity types have an array of labels that are indexed. If more than one label is provided, but the annotationType on the corresponding dataset is for a single class, the API rejects the create annotation request.
    """

    #: A constant which can be used with the entity_type property of a Entity.
    #: This constant has a value of "GENERIC"
    ENTITY_TYPE_GENERIC = "GENERIC"

    #: A constant which can be used with the entity_type property of a Entity.
    #: This constant has a value of "IMAGEOBJECTSELECTION"
    ENTITY_TYPE_IMAGEOBJECTSELECTION = "IMAGEOBJECTSELECTION"

    #: A constant which can be used with the entity_type property of a Entity.
    #: This constant has a value of "TEXTSELECTION"
    ENTITY_TYPE_TEXTSELECTION = "TEXTSELECTION"

    def __init__(self, **kwargs):
        """
        Initializes a new Entity object with values from keyword arguments. This class has the following subclasses and if you are using this class as input
        to a service operations then you should favor using a subclass over the base class:

        * :class:`~oci.data_labeling_service_dataplane.models.ImageObjectSelectionEntity`
        * :class:`~oci.data_labeling_service_dataplane.models.GenericEntity`
        * :class:`~oci.data_labeling_service_dataplane.models.TextSelectionEntity`

        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param entity_type:
            The value to assign to the entity_type property of this Entity.
            Allowed values for this property are: "GENERIC", "IMAGEOBJECTSELECTION", "TEXTSELECTION", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type entity_type: str

        """
        self.swagger_types = {
            'entity_type': 'str'
        }

        self.attribute_map = {
            'entity_type': 'entityType'
        }

        self._entity_type = None

    @staticmethod
    def get_subtype(object_dictionary):
        """
        Given the hash representation of a subtype of this class,
        use the info in the hash to return the class of the subtype.
        """
        type = object_dictionary['entityType']

        if type == 'IMAGEOBJECTSELECTION':
            return 'ImageObjectSelectionEntity'

        if type == 'GENERIC':
            return 'GenericEntity'

        if type == 'TEXTSELECTION':
            return 'TextSelectionEntity'
        else:
            return 'Entity'

    @property
    def entity_type(self):
        """
        **[Required]** Gets the entity_type of this Entity.
        The entity type described in the annotation.
        GENERIC  - An extensible entity type that is the base entity type for some annotation formats.
        IMAGEOBJECTSELECTION- - This allows the labeler to use specify a bounding polygon on the image to represent an object and apply labels to it.
        TEXTSELECTION - This allows the labeler to highlight text, by specifying an offset and a length, and apply labels to it.

        Allowed values for this property are: "GENERIC", "IMAGEOBJECTSELECTION", "TEXTSELECTION", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The entity_type of this Entity.
        :rtype: str
        """
        return self._entity_type

    @entity_type.setter
    def entity_type(self, entity_type):
        """
        Sets the entity_type of this Entity.
        The entity type described in the annotation.
        GENERIC  - An extensible entity type that is the base entity type for some annotation formats.
        IMAGEOBJECTSELECTION- - This allows the labeler to use specify a bounding polygon on the image to represent an object and apply labels to it.
        TEXTSELECTION - This allows the labeler to highlight text, by specifying an offset and a length, and apply labels to it.


        :param entity_type: The entity_type of this Entity.
        :type: str
        """
        allowed_values = ["GENERIC", "IMAGEOBJECTSELECTION", "TEXTSELECTION"]
        if not value_allowed_none_or_none_sentinel(entity_type, allowed_values):
            entity_type = 'UNKNOWN_ENUM_VALUE'
        self._entity_type = entity_type

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateSwiftPasswordDetails(object):
    """
    CreateSwiftPasswordDetails model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateSwiftPasswordDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param description:
            The value to assign to the description property of this CreateSwiftPasswordDetails.
        :type description: str

        """
        self.swagger_types = {
            'description': 'str'
        }

        self.attribute_map = {
            'description': 'description'
        }

        self._description = None

    @property
    def description(self):
        """
        **[Required]** Gets the description of this CreateSwiftPasswordDetails.
        The description you assign to the Swift password during creation. Does not have to be unique, and it's changeable.

        (For tenancies that support identity domains) You can have an empty description.


        :return: The description of this CreateSwiftPasswordDetails.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this CreateSwiftPasswordDetails.
        The description you assign to the Swift password during creation. Does not have to be unique, and it's changeable.

        (For tenancies that support identity domains) You can have an empty description.


        :param description: The description of this CreateSwiftPasswordDetails.
        :type: str
        """
        self._description = description

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class PrivateApplicationPackageSummary(object):
    """
    The model for a summary of a private application package.
    """

    #: A constant which can be used with the package_type property of a PrivateApplicationPackageSummary.
    #: This constant has a value of "STACK"
    PACKAGE_TYPE_STACK = "STACK"

    def __init__(self, **kwargs):
        """
        Initializes a new PrivateApplicationPackageSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param id:
            The value to assign to the id property of this PrivateApplicationPackageSummary.
        :type id: str

        :param private_application_id:
            The value to assign to the private_application_id property of this PrivateApplicationPackageSummary.
        :type private_application_id: str

        :param display_name:
            The value to assign to the display_name property of this PrivateApplicationPackageSummary.
        :type display_name: str

        :param version:
            The value to assign to the version property of this PrivateApplicationPackageSummary.
        :type version: str

        :param package_type:
            The value to assign to the package_type property of this PrivateApplicationPackageSummary.
            Allowed values for this property are: "STACK", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type package_type: str

        :param time_created:
            The value to assign to the time_created property of this PrivateApplicationPackageSummary.
        :type time_created: datetime

        """
        self.swagger_types = {
            'id': 'str',
            'private_application_id': 'str',
            'display_name': 'str',
            'version': 'str',
            'package_type': 'str',
            'time_created': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'private_application_id': 'privateApplicationId',
            'display_name': 'displayName',
            'version': 'version',
            'package_type': 'packageType',
            'time_created': 'timeCreated'
        }

        self._id = None
        self._private_application_id = None
        self._display_name = None
        self._version = None
        self._package_type = None
        self._time_created = None

    @property
    def id(self):
        """
        **[Required]** Gets the id of this PrivateApplicationPackageSummary.
        The `OCID`__ of the private application package.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The id of this PrivateApplicationPackageSummary.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this PrivateApplicationPackageSummary.
        The `OCID`__ of the private application package.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param id: The id of this PrivateApplicationPackageSummary.
        :type: str
        """
        self._id = id

    @property
    def private_application_id(self):
        """
        **[Required]** Gets the private_application_id of this PrivateApplicationPackageSummary.
        The `OCID`__ of the private application where the package is hosted.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The private_application_id of this PrivateApplicationPackageSummary.
        :rtype: str
        """
        return self._private_application_id

    @private_application_id.setter
    def private_application_id(self, private_application_id):
        """
        Sets the private_application_id of this PrivateApplicationPackageSummary.
        The `OCID`__ of the private application where the package is hosted.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param private_application_id: The private_application_id of this PrivateApplicationPackageSummary.
        :type: str
        """
        self._private_application_id = private_application_id

    @property
    def display_name(self):
        """
        Gets the display_name of this PrivateApplicationPackageSummary.
        The display name of the specified package.


        :return: The display_name of this PrivateApplicationPackageSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this PrivateApplicationPackageSummary.
        The display name of the specified package.


        :param display_name: The display_name of this PrivateApplicationPackageSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def version(self):
        """
        **[Required]** Gets the version of this PrivateApplicationPackageSummary.
        The version of the specified package.


        :return: The version of this PrivateApplicationPackageSummary.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this PrivateApplicationPackageSummary.
        The version of the specified package.


        :param version: The version of this PrivateApplicationPackageSummary.
        :type: str
        """
        self._version = version

    @property
    def package_type(self):
        """
        **[Required]** Gets the package_type of this PrivateApplicationPackageSummary.
        The type of the package.

        Allowed values for this property are: "STACK", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The package_type of this PrivateApplicationPackageSummary.
        :rtype: str
        """
        return self._package_type

    @package_type.setter
    def package_type(self, package_type):
        """
        Sets the package_type of this PrivateApplicationPackageSummary.
        The type of the package.


        :param package_type: The package_type of this PrivateApplicationPackageSummary.
        :type: str
        """
        allowed_values = ["STACK"]
        if not value_allowed_none_or_none_sentinel(package_type, allowed_values):
            package_type = 'UNKNOWN_ENUM_VALUE'
        self._package_type = package_type

    @property
    def time_created(self):
        """
        **[Required]** Gets the time_created of this PrivateApplicationPackageSummary.
        The date and time the private application package was created, expressed in `RFC 3339`__
        timestamp format.

        Example: `2021-05-27T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this PrivateApplicationPackageSummary.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this PrivateApplicationPackageSummary.
        The date and time the private application package was created, expressed in `RFC 3339`__
        timestamp format.

        Example: `2021-05-27T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this PrivateApplicationPackageSummary.
        :type: datetime
        """
        self._time_created = time_created

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class DiskPerformanceDetails(object):
    """
    Representation of disk performance detail parameters.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new DiskPerformanceDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param disk_iops:
            The value to assign to the disk_iops property of this DiskPerformanceDetails.
        :type disk_iops: float

        :param disk_throughput_in_mbps:
            The value to assign to the disk_throughput_in_mbps property of this DiskPerformanceDetails.
        :type disk_throughput_in_mbps: float

        """
        self.swagger_types = {
            'disk_iops': 'float',
            'disk_throughput_in_mbps': 'float'
        }

        self.attribute_map = {
            'disk_iops': 'diskIops',
            'disk_throughput_in_mbps': 'diskThroughputInMbps'
        }

        self._disk_iops = None
        self._disk_throughput_in_mbps = None

    @property
    def disk_iops(self):
        """
        **[Required]** Gets the disk_iops of this DiskPerformanceDetails.
        Disk IOPS in thousands.


        :return: The disk_iops of this DiskPerformanceDetails.
        :rtype: float
        """
        return self._disk_iops

    @disk_iops.setter
    def disk_iops(self, disk_iops):
        """
        Sets the disk_iops of this DiskPerformanceDetails.
        Disk IOPS in thousands.


        :param disk_iops: The disk_iops of this DiskPerformanceDetails.
        :type: float
        """
        self._disk_iops = disk_iops

    @property
    def disk_throughput_in_mbps(self):
        """
        **[Required]** Gets the disk_throughput_in_mbps of this DiskPerformanceDetails.
        Disk Throughput in Mbps.


        :return: The disk_throughput_in_mbps of this DiskPerformanceDetails.
        :rtype: float
        """
        return self._disk_throughput_in_mbps

    @disk_throughput_in_mbps.setter
    def disk_throughput_in_mbps(self, disk_throughput_in_mbps):
        """
        Sets the disk_throughput_in_mbps of this DiskPerformanceDetails.
        Disk Throughput in Mbps.


        :param disk_throughput_in_mbps: The disk_throughput_in_mbps of this DiskPerformanceDetails.
        :type: float
        """
        self._disk_throughput_in_mbps = disk_throughput_in_mbps

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class X509FederationRequest(object):
    """
    X509FederationRequest model.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new X509FederationRequest object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param certificate:
            The value to assign to the certificate property of this X509FederationRequest.
        :type certificate: str

        :param public_key:
            The value to assign to the public_key property of this X509FederationRequest.
        :type public_key: str

        :param intermediate_certificates:
            The value to assign to the intermediate_certificates property of this X509FederationRequest.
        :type intermediate_certificates: list[str]

        """
        self.swagger_types = {
            'certificate': 'str',
            'public_key': 'str',
            'intermediate_certificates': 'list[str]'
        }

        self.attribute_map = {
            'certificate': 'certificate',
            'public_key': 'publicKey',
            'intermediate_certificates': 'intermediateCertificates'
        }

        self._certificate = None
        self._public_key = None
        self._intermediate_certificates = None

    @property
    def certificate(self):
        """
        **[Required]** Gets the certificate of this X509FederationRequest.
        The x509 certificate of the service instance, issued by his CA.


        :return: The certificate of this X509FederationRequest.
        :rtype: str
        """
        return self._certificate

    @certificate.setter
    def certificate(self, certificate):
        """
        Sets the certificate of this X509FederationRequest.
        The x509 certificate of the service instance, issued by his CA.


        :param certificate: The certificate of this X509FederationRequest.
        :type: str
        """
        self._certificate = certificate

    @property
    def public_key(self):
        """
        **[Required]** Gets the public_key of this X509FederationRequest.
        A temporary public key, owned by the service. The service also owns the corresponding private key. This public
        key will by put inside the security token by the auth service after successful validation of the certificate.


        :return: The public_key of this X509FederationRequest.
        :rtype: str
        """
        return self._public_key

    @public_key.setter
    def public_key(self, public_key):
        """
        Sets the public_key of this X509FederationRequest.
        A temporary public key, owned by the service. The service also owns the corresponding private key. This public
        key will by put inside the security token by the auth service after successful validation of the certificate.


        :param public_key: The public_key of this X509FederationRequest.
        :type: str
        """
        self._public_key = public_key

    @property
    def intermediate_certificates(self):
        """
        Gets the intermediate_certificates of this X509FederationRequest.
        An array of intermediate certificates to form the chain from the leaf certificate to the root CA. If auth
        service already has the intermediate certificate(s), then this is not required.


        :return: The intermediate_certificates of this X509FederationRequest.
        :rtype: list[str]
        """
        return self._intermediate_certificates

    @intermediate_certificates.setter
    def intermediate_certificates(self, intermediate_certificates):
        """
        Sets the intermediate_certificates of this X509FederationRequest.
        An array of intermediate certificates to form the chain from the leaf certificate to the root CA. If auth
        service already has the intermediate certificate(s), then this is not required.


        :param intermediate_certificates: The intermediate_certificates of this X509FederationRequest.
        :type: list[str]
        """
        self._intermediate_certificates = intermediate_certificates

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateChildTenancyDetails(object):
    """
    The parameters for creating a child tenancy.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateChildTenancyDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param compartment_id:
            The value to assign to the compartment_id property of this CreateChildTenancyDetails.
        :type compartment_id: str

        :param tenancy_name:
            The value to assign to the tenancy_name property of this CreateChildTenancyDetails.
        :type tenancy_name: str

        :param home_region:
            The value to assign to the home_region property of this CreateChildTenancyDetails.
        :type home_region: str

        :param admin_email:
            The value to assign to the admin_email property of this CreateChildTenancyDetails.
        :type admin_email: str

        :param policy_name:
            The value to assign to the policy_name property of this CreateChildTenancyDetails.
        :type policy_name: str

        """
        self.swagger_types = {
            'compartment_id': 'str',
            'tenancy_name': 'str',
            'home_region': 'str',
            'admin_email': 'str',
            'policy_name': 'str'
        }

        self.attribute_map = {
            'compartment_id': 'compartmentId',
            'tenancy_name': 'tenancyName',
            'home_region': 'homeRegion',
            'admin_email': 'adminEmail',
            'policy_name': 'policyName'
        }

        self._compartment_id = None
        self._tenancy_name = None
        self._home_region = None
        self._admin_email = None
        self._policy_name = None

    @property
    def compartment_id(self):
        """
        **[Required]** Gets the compartment_id of this CreateChildTenancyDetails.
        The tenancy ID of the parent tenancy.


        :return: The compartment_id of this CreateChildTenancyDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this CreateChildTenancyDetails.
        The tenancy ID of the parent tenancy.


        :param compartment_id: The compartment_id of this CreateChildTenancyDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def tenancy_name(self):
        """
        **[Required]** Gets the tenancy_name of this CreateChildTenancyDetails.
        The tenancy name to use for the child tenancy.


        :return: The tenancy_name of this CreateChildTenancyDetails.
        :rtype: str
        """
        return self._tenancy_name

    @tenancy_name.setter
    def tenancy_name(self, tenancy_name):
        """
        Sets the tenancy_name of this CreateChildTenancyDetails.
        The tenancy name to use for the child tenancy.


        :param tenancy_name: The tenancy_name of this CreateChildTenancyDetails.
        :type: str
        """
        self._tenancy_name = tenancy_name

    @property
    def home_region(self):
        """
        **[Required]** Gets the home_region of this CreateChildTenancyDetails.
        The home region to use for the child tenancy. This must be a region where the parent tenancy is subscribed.


        :return: The home_region of this CreateChildTenancyDetails.
        :rtype: str
        """
        return self._home_region

    @home_region.setter
    def home_region(self, home_region):
        """
        Sets the home_region of this CreateChildTenancyDetails.
        The home region to use for the child tenancy. This must be a region where the parent tenancy is subscribed.


        :param home_region: The home_region of this CreateChildTenancyDetails.
        :type: str
        """
        self._home_region = home_region

    @property
    def admin_email(self):
        """
        **[Required]** Gets the admin_email of this CreateChildTenancyDetails.
        The email address of the administrator of the child tenancy.


        :return: The admin_email of this CreateChildTenancyDetails.
        :rtype: str
        """
        return self._admin_email

    @admin_email.setter
    def admin_email(self, admin_email):
        """
        Sets the admin_email of this CreateChildTenancyDetails.
        The email address of the administrator of the child tenancy.


        :param admin_email: The admin_email of this CreateChildTenancyDetails.
        :type: str
        """
        self._admin_email = admin_email

    @property
    def policy_name(self):
        """
        Gets the policy_name of this CreateChildTenancyDetails.
        The name to use for the administrator policy in the child tenancy. Must contain only letters and underscores.


        :return: The policy_name of this CreateChildTenancyDetails.
        :rtype: str
        """
        return self._policy_name

    @policy_name.setter
    def policy_name(self, policy_name):
        """
        Sets the policy_name of this CreateChildTenancyDetails.
        The name to use for the administrator policy in the child tenancy. Must contain only letters and underscores.


        :param policy_name: The policy_name of this CreateChildTenancyDetails.
        :type: str
        """
        self._policy_name = policy_name

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .activate_bds_metastore_configuration_details import ActivateBdsMetastoreConfigurationDetails
from .add_auto_scale_policy_details import AddAutoScalePolicyDetails
from .add_auto_scaling_configuration_details import AddAutoScalingConfigurationDetails
from .add_block_storage_details import AddBlockStorageDetails
from .add_cloud_sql_details import AddCloudSqlDetails
from .add_metric_based_horizontal_scaling_policy_details import AddMetricBasedHorizontalScalingPolicyDetails
from .add_metric_based_vertical_scaling_policy_details import AddMetricBasedVerticalScalingPolicyDetails
from .add_schedule_based_horizontal_scaling_policy_details import AddScheduleBasedHorizontalScalingPolicyDetails
from .add_schedule_based_vertical_scaling_policy_details import AddScheduleBasedVerticalScalingPolicyDetails
from .add_worker_nodes_details import AddWorkerNodesDetails
from .auto_scale_policy import AutoScalePolicy
from .auto_scale_policy_details import AutoScalePolicyDetails
from .auto_scale_policy_metric_rule import AutoScalePolicyMetricRule
from .auto_scale_policy_rule import AutoScalePolicyRule
from .auto_scaling_configuration import AutoScalingConfiguration
from .auto_scaling_configuration_summary import AutoScalingConfigurationSummary
from .bds_api_key import BdsApiKey
from .bds_api_key_summary import BdsApiKeySummary
from .bds_instance import BdsInstance
from .bds_instance_summary import BdsInstanceSummary
from .bds_metastore_configuration import BdsMetastoreConfiguration
from .bds_metastore_configuration_summary import BdsMetastoreConfigurationSummary
from .change_bds_instance_compartment_details import ChangeBdsInstanceCompartmentDetails
from .change_shape_details import ChangeShapeDetails
from .change_shape_nodes import ChangeShapeNodes
from .cloud_sql_details import CloudSqlDetails
from .cluster_details import ClusterDetails
from .create_bds_api_key_details import CreateBdsApiKeyDetails
from .create_bds_instance_details import CreateBdsInstanceDetails
from .create_bds_metastore_configuration_details import CreateBdsMetastoreConfigurationDetails
from .create_node_details import CreateNodeDetails
from .day_based_horizontal_scaling_schedule_details import DayBasedHorizontalScalingScheduleDetails
from .day_based_vertical_scaling_schedule_details import DayBasedVerticalScalingScheduleDetails
from .default_error import DefaultError
from .horizontal_scaling_schedule_details import HorizontalScalingScheduleDetails
from .install_patch_details import InstallPatchDetails
from .kerberos_details import KerberosDetails
from .metric_based_horizontal_scale_in_config import MetricBasedHorizontalScaleInConfig
from .metric_based_horizontal_scale_out_config import MetricBasedHorizontalScaleOutConfig
from .metric_based_horizontal_scaling_policy_details import MetricBasedHorizontalScalingPolicyDetails
from .metric_based_vertical_scale_down_config import MetricBasedVerticalScaleDownConfig
from .metric_based_vertical_scale_up_config import MetricBasedVerticalScaleUpConfig
from .metric_based_vertical_scaling_policy_details import MetricBasedVerticalScalingPolicyDetails
from .metric_threshold_rule import MetricThresholdRule
from .network_config import NetworkConfig
from .node import Node
from .patch_history_summary import PatchHistorySummary
from .patch_summary import PatchSummary
from .remove_auto_scaling_configuration_details import RemoveAutoScalingConfigurationDetails
from .remove_cloud_sql_details import RemoveCloudSqlDetails
from .remove_node_details import RemoveNodeDetails
from .restart_node_details import RestartNodeDetails
from .schedule_based_horizontal_scaling_policy_details import ScheduleBasedHorizontalScalingPolicyDetails
from .schedule_based_vertical_scaling_policy_details import ScheduleBasedVerticalScalingPolicyDetails
from .shape_config_details import ShapeConfigDetails
from .test_bds_metastore_configuration_details import TestBdsMetastoreConfigurationDetails
from .test_bds_object_storage_connection_details import TestBdsObjectStorageConnectionDetails
from .time_and_horizontal_scaling_config import TimeAndHorizontalScalingConfig
from .time_and_vertical_scaling_config import TimeAndVerticalScalingConfig
from .update_auto_scale_policy_details import UpdateAutoScalePolicyDetails
from .update_auto_scaling_configuration_details import UpdateAutoScalingConfigurationDetails
from .update_bds_instance_details import UpdateBdsInstanceDetails
from .update_bds_metastore_configuration_details import UpdateBdsMetastoreConfigurationDetails
from .update_metric_based_horizontal_scaling_policy_details import UpdateMetricBasedHorizontalScalingPolicyDetails
from .update_metric_based_vertical_scaling_policy_details import UpdateMetricBasedVerticalScalingPolicyDetails
from .update_schedule_based_horizontal_scaling_policy_details import UpdateScheduleBasedHorizontalScalingPolicyDetails
from .update_schedule_based_vertical_scaling_policy_details import UpdateScheduleBasedVerticalScalingPolicyDetails
from .vertical_scaling_schedule_details import VerticalScalingScheduleDetails
from .volume_attachment_detail import VolumeAttachmentDetail
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource

# Maps type names to classes for bds services.
bds_type_mapping = {
    "ActivateBdsMetastoreConfigurationDetails": ActivateBdsMetastoreConfigurationDetails,
    "AddAutoScalePolicyDetails": AddAutoScalePolicyDetails,
    "AddAutoScalingConfigurationDetails": AddAutoScalingConfigurationDetails,
    "AddBlockStorageDetails": AddBlockStorageDetails,
    "AddCloudSqlDetails": AddCloudSqlDetails,
    "AddMetricBasedHorizontalScalingPolicyDetails": AddMetricBasedHorizontalScalingPolicyDetails,
    "AddMetricBasedVerticalScalingPolicyDetails": AddMetricBasedVerticalScalingPolicyDetails,
    "AddScheduleBasedHorizontalScalingPolicyDetails": AddScheduleBasedHorizontalScalingPolicyDetails,
    "AddScheduleBasedVerticalScalingPolicyDetails": AddScheduleBasedVerticalScalingPolicyDetails,
    "AddWorkerNodesDetails": AddWorkerNodesDetails,
    "AutoScalePolicy": AutoScalePolicy,
    "AutoScalePolicyDetails": AutoScalePolicyDetails,
    "AutoScalePolicyMetricRule": AutoScalePolicyMetricRule,
    "AutoScalePolicyRule": AutoScalePolicyRule,
    "AutoScalingConfiguration": AutoScalingConfiguration,
    "AutoScalingConfigurationSummary": AutoScalingConfigurationSummary,
    "BdsApiKey": BdsApiKey,
    "BdsApiKeySummary": BdsApiKeySummary,
    "BdsInstance": BdsInstance,
    "BdsInstanceSummary": BdsInstanceSummary,
    "BdsMetastoreConfiguration": BdsMetastoreConfiguration,
    "BdsMetastoreConfigurationSummary": BdsMetastoreConfigurationSummary,
    "ChangeBdsInstanceCompartmentDetails": ChangeBdsInstanceCompartmentDetails,
    "ChangeShapeDetails": ChangeShapeDetails,
    "ChangeShapeNodes": ChangeShapeNodes,
    "CloudSqlDetails": CloudSqlDetails,
    "ClusterDetails": ClusterDetails,
    "CreateBdsApiKeyDetails": CreateBdsApiKeyDetails,
    "CreateBdsInstanceDetails": CreateBdsInstanceDetails,
    "CreateBdsMetastoreConfigurationDetails": CreateBdsMetastoreConfigurationDetails,
    "CreateNodeDetails": CreateNodeDetails,
    "DayBasedHorizontalScalingScheduleDetails": DayBasedHorizontalScalingScheduleDetails,
    "DayBasedVerticalScalingScheduleDetails": DayBasedVerticalScalingScheduleDetails,
    "DefaultError": DefaultError,
    "HorizontalScalingScheduleDetails": HorizontalScalingScheduleDetails,
    "InstallPatchDetails": InstallPatchDetails,
    "KerberosDetails": KerberosDetails,
    "MetricBasedHorizontalScaleInConfig": MetricBasedHorizontalScaleInConfig,
    "MetricBasedHorizontalScaleOutConfig": MetricBasedHorizontalScaleOutConfig,
    "MetricBasedHorizontalScalingPolicyDetails": MetricBasedHorizontalScalingPolicyDetails,
    "MetricBasedVerticalScaleDownConfig": MetricBasedVerticalScaleDownConfig,
    "MetricBasedVerticalScaleUpConfig": MetricBasedVerticalScaleUpConfig,
    "MetricBasedVerticalScalingPolicyDetails": MetricBasedVerticalScalingPolicyDetails,
    "MetricThresholdRule": MetricThresholdRule,
    "NetworkConfig": NetworkConfig,
    "Node": Node,
    "PatchHistorySummary": PatchHistorySummary,
    "PatchSummary": PatchSummary,
    "RemoveAutoScalingConfigurationDetails": RemoveAutoScalingConfigurationDetails,
    "RemoveCloudSqlDetails": RemoveCloudSqlDetails,
    "RemoveNodeDetails": RemoveNodeDetails,
    "RestartNodeDetails": RestartNodeDetails,
    "ScheduleBasedHorizontalScalingPolicyDetails": ScheduleBasedHorizontalScalingPolicyDetails,
    "ScheduleBasedVerticalScalingPolicyDetails": ScheduleBasedVerticalScalingPolicyDetails,
    "ShapeConfigDetails": ShapeConfigDetails,
    "TestBdsMetastoreConfigurationDetails": TestBdsMetastoreConfigurationDetails,
    "TestBdsObjectStorageConnectionDetails": TestBdsObjectStorageConnectionDetails,
    "TimeAndHorizontalScalingConfig": TimeAndHorizontalScalingConfig,
    "TimeAndVerticalScalingConfig": TimeAndVerticalScalingConfig,
    "UpdateAutoScalePolicyDetails": UpdateAutoScalePolicyDetails,
    "UpdateAutoScalingConfigurationDetails": UpdateAutoScalingConfigurationDetails,
    "UpdateBdsInstanceDetails": UpdateBdsInstanceDetails,
    "UpdateBdsMetastoreConfigurationDetails": UpdateBdsMetastoreConfigurationDetails,
    "UpdateMetricBasedHorizontalScalingPolicyDetails": UpdateMetricBasedHorizontalScalingPolicyDetails,
    "UpdateMetricBasedVerticalScalingPolicyDetails": UpdateMetricBasedVerticalScalingPolicyDetails,
    "UpdateScheduleBasedHorizontalScalingPolicyDetails": UpdateScheduleBasedHorizontalScalingPolicyDetails,
    "UpdateScheduleBasedVerticalScalingPolicyDetails": UpdateScheduleBasedVerticalScalingPolicyDetails,
    "VerticalScalingScheduleDetails": VerticalScalingScheduleDetails,
    "VolumeAttachmentDetail": VolumeAttachmentDetail,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource
}



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsResourceCategory(object):
    """
    A resource and its category.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsResourceCategory object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param resource_id:
            The value to assign to the resource_id property of this LogAnalyticsResourceCategory.
        :type resource_id: str

        :param resource_type:
            The value to assign to the resource_type property of this LogAnalyticsResourceCategory.
        :type resource_type: str

        :param category_name:
            The value to assign to the category_name property of this LogAnalyticsResourceCategory.
        :type category_name: str

        :param is_system:
            The value to assign to the is_system property of this LogAnalyticsResourceCategory.
        :type is_system: bool

        """
        self.swagger_types = {
            'resource_id': 'str',
            'resource_type': 'str',
            'category_name': 'str',
            'is_system': 'bool'
        }

        self.attribute_map = {
            'resource_id': 'resourceId',
            'resource_type': 'resourceType',
            'category_name': 'categoryName',
            'is_system': 'isSystem'
        }

        self._resource_id = None
        self._resource_type = None
        self._category_name = None
        self._is_system = None

    @property
    def resource_id(self):
        """
        Gets the resource_id of this LogAnalyticsResourceCategory.
        The unique identifier of the resource, usually a name or ocid.


        :return: The resource_id of this LogAnalyticsResourceCategory.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """
        Sets the resource_id of this LogAnalyticsResourceCategory.
        The unique identifier of the resource, usually a name or ocid.


        :param resource_id: The resource_id of this LogAnalyticsResourceCategory.
        :type: str
        """
        self._resource_id = resource_id

    @property
    def resource_type(self):
        """
        Gets the resource_type of this LogAnalyticsResourceCategory.
        The resource type.


        :return: The resource_type of this LogAnalyticsResourceCategory.
        :rtype: str
        """
        return self._resource_type

    @resource_type.setter
    def resource_type(self, resource_type):
        """
        Sets the resource_type of this LogAnalyticsResourceCategory.
        The resource type.


        :param resource_type: The resource_type of this LogAnalyticsResourceCategory.
        :type: str
        """
        self._resource_type = resource_type

    @property
    def category_name(self):
        """
        Gets the category_name of this LogAnalyticsResourceCategory.
        The category name to which this resource belongs.


        :return: The category_name of this LogAnalyticsResourceCategory.
        :rtype: str
        """
        return self._category_name

    @category_name.setter
    def category_name(self, category_name):
        """
        Sets the category_name of this LogAnalyticsResourceCategory.
        The category name to which this resource belongs.


        :param category_name: The category_name of this LogAnalyticsResourceCategory.
        :type: str
        """
        self._category_name = category_name

    @property
    def is_system(self):
        """
        Gets the is_system of this LogAnalyticsResourceCategory.
        The system flag. A value of false denotes a user-created category assignment.
        A value of true denotes an Oracle-defined category assignment.


        :return: The is_system of this LogAnalyticsResourceCategory.
        :rtype: bool
        """
        return self._is_system

    @is_system.setter
    def is_system(self, is_system):
        """
        Sets the is_system of this LogAnalyticsResourceCategory.
        The system flag. A value of false denotes a user-created category assignment.
        A value of true denotes an Oracle-defined category assignment.


        :param is_system: The is_system of this LogAnalyticsResourceCategory.
        :type: bool
        """
        self._is_system = is_system

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2022, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_column_source_details import CreateColumnSourceDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateColumnSourceFromSdmDetails(CreateColumnSourceDetails):
    """
    Details of the sensitive data model to be associated as the column source with a masking policy.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateColumnSourceFromSdmDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.data_safe.models.CreateColumnSourceFromSdmDetails.column_source` attribute
        of this class is ``SENSITIVE_DATA_MODEL`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param column_source:
            The value to assign to the column_source property of this CreateColumnSourceFromSdmDetails.
            Allowed values for this property are: "TARGET", "SENSITIVE_DATA_MODEL"
        :type column_source: str

        :param sensitive_data_model_id:
            The value to assign to the sensitive_data_model_id property of this CreateColumnSourceFromSdmDetails.
        :type sensitive_data_model_id: str

        """
        self.swagger_types = {
            'column_source': 'str',
            'sensitive_data_model_id': 'str'
        }

        self.attribute_map = {
            'column_source': 'columnSource',
            'sensitive_data_model_id': 'sensitiveDataModelId'
        }

        self._column_source = None
        self._sensitive_data_model_id = None
        self._column_source = 'SENSITIVE_DATA_MODEL'

    @property
    def sensitive_data_model_id(self):
        """
        **[Required]** Gets the sensitive_data_model_id of this CreateColumnSourceFromSdmDetails.
        The OCID of the sensitive data model to be associated as the column source with the masking policy.


        :return: The sensitive_data_model_id of this CreateColumnSourceFromSdmDetails.
        :rtype: str
        """
        return self._sensitive_data_model_id

    @sensitive_data_model_id.setter
    def sensitive_data_model_id(self, sensitive_data_model_id):
        """
        Sets the sensitive_data_model_id of this CreateColumnSourceFromSdmDetails.
        The OCID of the sensitive data model to be associated as the column source with the masking policy.


        :param sensitive_data_model_id: The sensitive_data_model_id of this CreateColumnSourceFromSdmDetails.
        :type: str
        """
        self._sensitive_data_model_id = sensitive_data_model_id

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
